import types
from typing import Any, overload

import proto
from google.oauth2.credentials import Credentials
from google.protobuf.message import Message
from typing_extensions import Literal

# NOTE: This is a workaround to keep imports inside the "Autogenerated" section even when ruff reorders them,
# since those comments are used as markers for generating/replacing imports.
#
# isort: split

# Autogenerated service imports
import google.ads.googleads.v20.services.services.account_budget_proposal_service
import google.ads.googleads.v20.services.services.account_link_service
import google.ads.googleads.v20.services.services.ad_group_ad_label_service
import google.ads.googleads.v20.services.services.ad_group_ad_service
import google.ads.googleads.v20.services.services.ad_group_asset_service
import google.ads.googleads.v20.services.services.ad_group_asset_set_service
import google.ads.googleads.v20.services.services.ad_group_bid_modifier_service
import google.ads.googleads.v20.services.services.ad_group_criterion_customizer_service
import google.ads.googleads.v20.services.services.ad_group_criterion_label_service
import google.ads.googleads.v20.services.services.ad_group_criterion_service
import google.ads.googleads.v20.services.services.ad_group_customizer_service
import google.ads.googleads.v20.services.services.ad_group_label_service
import google.ads.googleads.v20.services.services.ad_group_service
import google.ads.googleads.v20.services.services.ad_parameter_service
import google.ads.googleads.v20.services.services.ad_service
import google.ads.googleads.v20.services.services.asset_group_asset_service
import google.ads.googleads.v20.services.services.asset_group_listing_group_filter_service
import google.ads.googleads.v20.services.services.asset_group_service
import google.ads.googleads.v20.services.services.asset_group_signal_service
import google.ads.googleads.v20.services.services.asset_service
import google.ads.googleads.v20.services.services.asset_set_asset_service
import google.ads.googleads.v20.services.services.asset_set_service
import google.ads.googleads.v20.services.services.audience_insights_service
import google.ads.googleads.v20.services.services.audience_service
import google.ads.googleads.v20.services.services.batch_job_service
import google.ads.googleads.v20.services.services.bidding_data_exclusion_service
import google.ads.googleads.v20.services.services.bidding_seasonality_adjustment_service
import google.ads.googleads.v20.services.services.bidding_strategy_service
import google.ads.googleads.v20.services.services.billing_setup_service
import google.ads.googleads.v20.services.services.brand_suggestion_service
import google.ads.googleads.v20.services.services.campaign_asset_service
import google.ads.googleads.v20.services.services.campaign_asset_set_service
import google.ads.googleads.v20.services.services.campaign_bid_modifier_service
import google.ads.googleads.v20.services.services.campaign_budget_service
import google.ads.googleads.v20.services.services.campaign_conversion_goal_service
import google.ads.googleads.v20.services.services.campaign_criterion_service
import google.ads.googleads.v20.services.services.campaign_customizer_service
import google.ads.googleads.v20.services.services.campaign_draft_service
import google.ads.googleads.v20.services.services.campaign_group_service
import google.ads.googleads.v20.services.services.campaign_label_service
import google.ads.googleads.v20.services.services.campaign_lifecycle_goal_service
import google.ads.googleads.v20.services.services.campaign_service
import google.ads.googleads.v20.services.services.campaign_shared_set_service
import google.ads.googleads.v20.services.services.content_creator_insights_service
import google.ads.googleads.v20.services.services.conversion_action_service
import google.ads.googleads.v20.services.services.conversion_adjustment_upload_service
import google.ads.googleads.v20.services.services.conversion_custom_variable_service
import google.ads.googleads.v20.services.services.conversion_goal_campaign_config_service
import google.ads.googleads.v20.services.services.conversion_upload_service
import google.ads.googleads.v20.services.services.conversion_value_rule_service
import google.ads.googleads.v20.services.services.conversion_value_rule_set_service
import google.ads.googleads.v20.services.services.custom_audience_service
import google.ads.googleads.v20.services.services.custom_conversion_goal_service
import google.ads.googleads.v20.services.services.custom_interest_service
import google.ads.googleads.v20.services.services.customer_asset_service
import google.ads.googleads.v20.services.services.customer_asset_set_service
import google.ads.googleads.v20.services.services.customer_client_link_service
import google.ads.googleads.v20.services.services.customer_conversion_goal_service
import google.ads.googleads.v20.services.services.customer_customizer_service
import google.ads.googleads.v20.services.services.customer_label_service
import google.ads.googleads.v20.services.services.customer_lifecycle_goal_service
import google.ads.googleads.v20.services.services.customer_manager_link_service
import google.ads.googleads.v20.services.services.customer_negative_criterion_service
import google.ads.googleads.v20.services.services.customer_service
import google.ads.googleads.v20.services.services.customer_sk_ad_network_conversion_value_schema_service
import google.ads.googleads.v20.services.services.customer_user_access_invitation_service
import google.ads.googleads.v20.services.services.customer_user_access_service
import google.ads.googleads.v20.services.services.customizer_attribute_service
import google.ads.googleads.v20.services.services.data_link_service
import google.ads.googleads.v20.services.services.experiment_arm_service
import google.ads.googleads.v20.services.services.experiment_service
import google.ads.googleads.v20.services.services.geo_target_constant_service
import google.ads.googleads.v20.services.services.google_ads_field_service
import google.ads.googleads.v20.services.services.google_ads_service
import google.ads.googleads.v20.services.services.identity_verification_service
import google.ads.googleads.v20.services.services.invoice_service
import google.ads.googleads.v20.services.services.keyword_plan_ad_group_keyword_service
import google.ads.googleads.v20.services.services.keyword_plan_ad_group_service
import google.ads.googleads.v20.services.services.keyword_plan_campaign_keyword_service
import google.ads.googleads.v20.services.services.keyword_plan_campaign_service
import google.ads.googleads.v20.services.services.keyword_plan_idea_service
import google.ads.googleads.v20.services.services.keyword_plan_service
import google.ads.googleads.v20.services.services.keyword_theme_constant_service
import google.ads.googleads.v20.services.services.label_service
import google.ads.googleads.v20.services.services.local_services_lead_service
import google.ads.googleads.v20.services.services.offline_user_data_job_service
import google.ads.googleads.v20.services.services.payments_account_service
import google.ads.googleads.v20.services.services.product_link_invitation_service
import google.ads.googleads.v20.services.services.product_link_service
import google.ads.googleads.v20.services.services.reach_plan_service
import google.ads.googleads.v20.services.services.recommendation_service
import google.ads.googleads.v20.services.services.recommendation_subscription_service
import google.ads.googleads.v20.services.services.remarketing_action_service
import google.ads.googleads.v20.services.services.shareable_preview_service
import google.ads.googleads.v20.services.services.shared_criterion_service
import google.ads.googleads.v20.services.services.shared_set_service
import google.ads.googleads.v20.services.services.smart_campaign_setting_service
import google.ads.googleads.v20.services.services.smart_campaign_suggest_service
import google.ads.googleads.v20.services.services.third_party_app_analytics_link_service
import google.ads.googleads.v20.services.services.travel_asset_suggestion_service
import google.ads.googleads.v20.services.services.user_data_service
import google.ads.googleads.v20.services.services.user_list_customer_type_service
import google.ads.googleads.v20.services.services.user_list_service
import google.ads.googleads.v21.services.services.account_budget_proposal_service
import google.ads.googleads.v21.services.services.account_link_service
import google.ads.googleads.v21.services.services.ad_group_ad_label_service
import google.ads.googleads.v21.services.services.ad_group_ad_service
import google.ads.googleads.v21.services.services.ad_group_asset_service
import google.ads.googleads.v21.services.services.ad_group_asset_set_service
import google.ads.googleads.v21.services.services.ad_group_bid_modifier_service
import google.ads.googleads.v21.services.services.ad_group_criterion_customizer_service
import google.ads.googleads.v21.services.services.ad_group_criterion_label_service
import google.ads.googleads.v21.services.services.ad_group_criterion_service
import google.ads.googleads.v21.services.services.ad_group_customizer_service
import google.ads.googleads.v21.services.services.ad_group_label_service
import google.ads.googleads.v21.services.services.ad_group_service
import google.ads.googleads.v21.services.services.ad_parameter_service
import google.ads.googleads.v21.services.services.ad_service
import google.ads.googleads.v21.services.services.asset_group_asset_service
import google.ads.googleads.v21.services.services.asset_group_listing_group_filter_service
import google.ads.googleads.v21.services.services.asset_group_service
import google.ads.googleads.v21.services.services.asset_group_signal_service
import google.ads.googleads.v21.services.services.asset_service
import google.ads.googleads.v21.services.services.asset_set_asset_service
import google.ads.googleads.v21.services.services.asset_set_service
import google.ads.googleads.v21.services.services.audience_insights_service
import google.ads.googleads.v21.services.services.audience_service
import google.ads.googleads.v21.services.services.automatically_created_asset_removal_service
import google.ads.googleads.v21.services.services.batch_job_service
import google.ads.googleads.v21.services.services.bidding_data_exclusion_service
import google.ads.googleads.v21.services.services.bidding_seasonality_adjustment_service
import google.ads.googleads.v21.services.services.bidding_strategy_service
import google.ads.googleads.v21.services.services.billing_setup_service
import google.ads.googleads.v21.services.services.brand_suggestion_service
import google.ads.googleads.v21.services.services.campaign_asset_service
import google.ads.googleads.v21.services.services.campaign_asset_set_service
import google.ads.googleads.v21.services.services.campaign_bid_modifier_service
import google.ads.googleads.v21.services.services.campaign_budget_service
import google.ads.googleads.v21.services.services.campaign_conversion_goal_service
import google.ads.googleads.v21.services.services.campaign_criterion_service
import google.ads.googleads.v21.services.services.campaign_customizer_service
import google.ads.googleads.v21.services.services.campaign_draft_service
import google.ads.googleads.v21.services.services.campaign_group_service
import google.ads.googleads.v21.services.services.campaign_label_service
import google.ads.googleads.v21.services.services.campaign_lifecycle_goal_service
import google.ads.googleads.v21.services.services.campaign_service
import google.ads.googleads.v21.services.services.campaign_shared_set_service
import google.ads.googleads.v21.services.services.content_creator_insights_service
import google.ads.googleads.v21.services.services.conversion_action_service
import google.ads.googleads.v21.services.services.conversion_adjustment_upload_service
import google.ads.googleads.v21.services.services.conversion_custom_variable_service
import google.ads.googleads.v21.services.services.conversion_goal_campaign_config_service
import google.ads.googleads.v21.services.services.conversion_upload_service
import google.ads.googleads.v21.services.services.conversion_value_rule_service
import google.ads.googleads.v21.services.services.conversion_value_rule_set_service
import google.ads.googleads.v21.services.services.custom_audience_service
import google.ads.googleads.v21.services.services.custom_conversion_goal_service
import google.ads.googleads.v21.services.services.custom_interest_service
import google.ads.googleads.v21.services.services.customer_asset_service
import google.ads.googleads.v21.services.services.customer_asset_set_service
import google.ads.googleads.v21.services.services.customer_client_link_service
import google.ads.googleads.v21.services.services.customer_conversion_goal_service
import google.ads.googleads.v21.services.services.customer_customizer_service
import google.ads.googleads.v21.services.services.customer_label_service
import google.ads.googleads.v21.services.services.customer_lifecycle_goal_service
import google.ads.googleads.v21.services.services.customer_manager_link_service
import google.ads.googleads.v21.services.services.customer_negative_criterion_service
import google.ads.googleads.v21.services.services.customer_service
import google.ads.googleads.v21.services.services.customer_sk_ad_network_conversion_value_schema_service
import google.ads.googleads.v21.services.services.customer_user_access_invitation_service
import google.ads.googleads.v21.services.services.customer_user_access_service
import google.ads.googleads.v21.services.services.customizer_attribute_service
import google.ads.googleads.v21.services.services.data_link_service
import google.ads.googleads.v21.services.services.experiment_arm_service
import google.ads.googleads.v21.services.services.experiment_service
import google.ads.googleads.v21.services.services.geo_target_constant_service
import google.ads.googleads.v21.services.services.google_ads_field_service
import google.ads.googleads.v21.services.services.google_ads_service
import google.ads.googleads.v21.services.services.identity_verification_service
import google.ads.googleads.v21.services.services.invoice_service
import google.ads.googleads.v21.services.services.keyword_plan_ad_group_keyword_service
import google.ads.googleads.v21.services.services.keyword_plan_ad_group_service
import google.ads.googleads.v21.services.services.keyword_plan_campaign_keyword_service
import google.ads.googleads.v21.services.services.keyword_plan_campaign_service
import google.ads.googleads.v21.services.services.keyword_plan_idea_service
import google.ads.googleads.v21.services.services.keyword_plan_service
import google.ads.googleads.v21.services.services.keyword_theme_constant_service
import google.ads.googleads.v21.services.services.label_service
import google.ads.googleads.v21.services.services.local_services_lead_service
import google.ads.googleads.v21.services.services.offline_user_data_job_service
import google.ads.googleads.v21.services.services.payments_account_service
import google.ads.googleads.v21.services.services.product_link_invitation_service
import google.ads.googleads.v21.services.services.product_link_service
import google.ads.googleads.v21.services.services.reach_plan_service
import google.ads.googleads.v21.services.services.recommendation_service
import google.ads.googleads.v21.services.services.recommendation_subscription_service
import google.ads.googleads.v21.services.services.remarketing_action_service
import google.ads.googleads.v21.services.services.shareable_preview_service
import google.ads.googleads.v21.services.services.shared_criterion_service
import google.ads.googleads.v21.services.services.shared_set_service
import google.ads.googleads.v21.services.services.smart_campaign_setting_service
import google.ads.googleads.v21.services.services.smart_campaign_suggest_service
import google.ads.googleads.v21.services.services.third_party_app_analytics_link_service
import google.ads.googleads.v21.services.services.travel_asset_suggestion_service
import google.ads.googleads.v21.services.services.user_data_service
import google.ads.googleads.v21.services.services.user_list_customer_type_service
import google.ads.googleads.v21.services.services.user_list_service
import google.ads.googleads.v22.services.services.account_budget_proposal_service
import google.ads.googleads.v22.services.services.account_link_service
import google.ads.googleads.v22.services.services.ad_group_ad_label_service
import google.ads.googleads.v22.services.services.ad_group_ad_service
import google.ads.googleads.v22.services.services.ad_group_asset_service
import google.ads.googleads.v22.services.services.ad_group_asset_set_service
import google.ads.googleads.v22.services.services.ad_group_bid_modifier_service
import google.ads.googleads.v22.services.services.ad_group_criterion_customizer_service
import google.ads.googleads.v22.services.services.ad_group_criterion_label_service
import google.ads.googleads.v22.services.services.ad_group_criterion_service
import google.ads.googleads.v22.services.services.ad_group_customizer_service
import google.ads.googleads.v22.services.services.ad_group_label_service
import google.ads.googleads.v22.services.services.ad_group_service
import google.ads.googleads.v22.services.services.ad_parameter_service
import google.ads.googleads.v22.services.services.ad_service
import google.ads.googleads.v22.services.services.asset_generation_service
import google.ads.googleads.v22.services.services.asset_group_asset_service
import google.ads.googleads.v22.services.services.asset_group_listing_group_filter_service
import google.ads.googleads.v22.services.services.asset_group_service
import google.ads.googleads.v22.services.services.asset_group_signal_service
import google.ads.googleads.v22.services.services.asset_service
import google.ads.googleads.v22.services.services.asset_set_asset_service
import google.ads.googleads.v22.services.services.asset_set_service
import google.ads.googleads.v22.services.services.audience_insights_service
import google.ads.googleads.v22.services.services.audience_service
import google.ads.googleads.v22.services.services.automatically_created_asset_removal_service
import google.ads.googleads.v22.services.services.batch_job_service
import google.ads.googleads.v22.services.services.bidding_data_exclusion_service
import google.ads.googleads.v22.services.services.bidding_seasonality_adjustment_service
import google.ads.googleads.v22.services.services.bidding_strategy_service
import google.ads.googleads.v22.services.services.billing_setup_service
import google.ads.googleads.v22.services.services.brand_suggestion_service
import google.ads.googleads.v22.services.services.campaign_asset_service
import google.ads.googleads.v22.services.services.campaign_asset_set_service
import google.ads.googleads.v22.services.services.campaign_bid_modifier_service
import google.ads.googleads.v22.services.services.campaign_budget_service
import google.ads.googleads.v22.services.services.campaign_conversion_goal_service
import google.ads.googleads.v22.services.services.campaign_criterion_service
import google.ads.googleads.v22.services.services.campaign_customizer_service
import google.ads.googleads.v22.services.services.campaign_draft_service
import google.ads.googleads.v22.services.services.campaign_goal_config_service
import google.ads.googleads.v22.services.services.campaign_group_service
import google.ads.googleads.v22.services.services.campaign_label_service
import google.ads.googleads.v22.services.services.campaign_lifecycle_goal_service
import google.ads.googleads.v22.services.services.campaign_service
import google.ads.googleads.v22.services.services.campaign_shared_set_service
import google.ads.googleads.v22.services.services.content_creator_insights_service
import google.ads.googleads.v22.services.services.conversion_action_service
import google.ads.googleads.v22.services.services.conversion_adjustment_upload_service
import google.ads.googleads.v22.services.services.conversion_custom_variable_service
import google.ads.googleads.v22.services.services.conversion_goal_campaign_config_service
import google.ads.googleads.v22.services.services.conversion_upload_service
import google.ads.googleads.v22.services.services.conversion_value_rule_service
import google.ads.googleads.v22.services.services.conversion_value_rule_set_service
import google.ads.googleads.v22.services.services.custom_audience_service
import google.ads.googleads.v22.services.services.custom_conversion_goal_service
import google.ads.googleads.v22.services.services.custom_interest_service
import google.ads.googleads.v22.services.services.customer_asset_service
import google.ads.googleads.v22.services.services.customer_asset_set_service
import google.ads.googleads.v22.services.services.customer_client_link_service
import google.ads.googleads.v22.services.services.customer_conversion_goal_service
import google.ads.googleads.v22.services.services.customer_customizer_service
import google.ads.googleads.v22.services.services.customer_label_service
import google.ads.googleads.v22.services.services.customer_lifecycle_goal_service
import google.ads.googleads.v22.services.services.customer_manager_link_service
import google.ads.googleads.v22.services.services.customer_negative_criterion_service
import google.ads.googleads.v22.services.services.customer_service
import google.ads.googleads.v22.services.services.customer_sk_ad_network_conversion_value_schema_service
import google.ads.googleads.v22.services.services.customer_user_access_invitation_service
import google.ads.googleads.v22.services.services.customer_user_access_service
import google.ads.googleads.v22.services.services.customizer_attribute_service
import google.ads.googleads.v22.services.services.data_link_service
import google.ads.googleads.v22.services.services.experiment_arm_service
import google.ads.googleads.v22.services.services.experiment_service
import google.ads.googleads.v22.services.services.geo_target_constant_service
import google.ads.googleads.v22.services.services.goal_service
import google.ads.googleads.v22.services.services.google_ads_field_service
import google.ads.googleads.v22.services.services.google_ads_service
import google.ads.googleads.v22.services.services.identity_verification_service
import google.ads.googleads.v22.services.services.invoice_service
import google.ads.googleads.v22.services.services.keyword_plan_ad_group_keyword_service
import google.ads.googleads.v22.services.services.keyword_plan_ad_group_service
import google.ads.googleads.v22.services.services.keyword_plan_campaign_keyword_service
import google.ads.googleads.v22.services.services.keyword_plan_campaign_service
import google.ads.googleads.v22.services.services.keyword_plan_idea_service
import google.ads.googleads.v22.services.services.keyword_plan_service
import google.ads.googleads.v22.services.services.keyword_theme_constant_service
import google.ads.googleads.v22.services.services.label_service
import google.ads.googleads.v22.services.services.local_services_lead_service
import google.ads.googleads.v22.services.services.offline_user_data_job_service
import google.ads.googleads.v22.services.services.payments_account_service
import google.ads.googleads.v22.services.services.product_link_invitation_service
import google.ads.googleads.v22.services.services.product_link_service
import google.ads.googleads.v22.services.services.reach_plan_service
import google.ads.googleads.v22.services.services.recommendation_service
import google.ads.googleads.v22.services.services.recommendation_subscription_service
import google.ads.googleads.v22.services.services.remarketing_action_service
import google.ads.googleads.v22.services.services.shareable_preview_service
import google.ads.googleads.v22.services.services.shared_criterion_service
import google.ads.googleads.v22.services.services.shared_set_service
import google.ads.googleads.v22.services.services.smart_campaign_setting_service
import google.ads.googleads.v22.services.services.smart_campaign_suggest_service
import google.ads.googleads.v22.services.services.third_party_app_analytics_link_service
import google.ads.googleads.v22.services.services.travel_asset_suggestion_service
import google.ads.googleads.v22.services.services.user_data_service
import google.ads.googleads.v22.services.services.user_list_customer_type_service
import google.ads.googleads.v22.services.services.user_list_service
import google.ads.googleads.v23.services.services.account_budget_proposal_service
import google.ads.googleads.v23.services.services.account_link_service
import google.ads.googleads.v23.services.services.ad_group_ad_label_service
import google.ads.googleads.v23.services.services.ad_group_ad_service
import google.ads.googleads.v23.services.services.ad_group_asset_service
import google.ads.googleads.v23.services.services.ad_group_asset_set_service
import google.ads.googleads.v23.services.services.ad_group_bid_modifier_service
import google.ads.googleads.v23.services.services.ad_group_criterion_customizer_service
import google.ads.googleads.v23.services.services.ad_group_criterion_label_service
import google.ads.googleads.v23.services.services.ad_group_criterion_service
import google.ads.googleads.v23.services.services.ad_group_customizer_service
import google.ads.googleads.v23.services.services.ad_group_label_service
import google.ads.googleads.v23.services.services.ad_group_service
import google.ads.googleads.v23.services.services.ad_parameter_service
import google.ads.googleads.v23.services.services.ad_service
import google.ads.googleads.v23.services.services.asset_generation_service
import google.ads.googleads.v23.services.services.asset_group_asset_service
import google.ads.googleads.v23.services.services.asset_group_listing_group_filter_service
import google.ads.googleads.v23.services.services.asset_group_service
import google.ads.googleads.v23.services.services.asset_group_signal_service
import google.ads.googleads.v23.services.services.asset_service
import google.ads.googleads.v23.services.services.asset_set_asset_service
import google.ads.googleads.v23.services.services.asset_set_service
import google.ads.googleads.v23.services.services.audience_insights_service
import google.ads.googleads.v23.services.services.audience_service
import google.ads.googleads.v23.services.services.automatically_created_asset_removal_service
import google.ads.googleads.v23.services.services.batch_job_service
import google.ads.googleads.v23.services.services.benchmarks_service
import google.ads.googleads.v23.services.services.bidding_data_exclusion_service
import google.ads.googleads.v23.services.services.bidding_seasonality_adjustment_service
import google.ads.googleads.v23.services.services.bidding_strategy_service
import google.ads.googleads.v23.services.services.billing_setup_service
import google.ads.googleads.v23.services.services.brand_suggestion_service
import google.ads.googleads.v23.services.services.campaign_asset_service
import google.ads.googleads.v23.services.services.campaign_asset_set_service
import google.ads.googleads.v23.services.services.campaign_bid_modifier_service
import google.ads.googleads.v23.services.services.campaign_budget_service
import google.ads.googleads.v23.services.services.campaign_conversion_goal_service
import google.ads.googleads.v23.services.services.campaign_criterion_service
import google.ads.googleads.v23.services.services.campaign_customizer_service
import google.ads.googleads.v23.services.services.campaign_draft_service
import google.ads.googleads.v23.services.services.campaign_goal_config_service
import google.ads.googleads.v23.services.services.campaign_group_service
import google.ads.googleads.v23.services.services.campaign_label_service
import google.ads.googleads.v23.services.services.campaign_lifecycle_goal_service
import google.ads.googleads.v23.services.services.campaign_service
import google.ads.googleads.v23.services.services.campaign_shared_set_service
import google.ads.googleads.v23.services.services.content_creator_insights_service
import google.ads.googleads.v23.services.services.conversion_action_service
import google.ads.googleads.v23.services.services.conversion_adjustment_upload_service
import google.ads.googleads.v23.services.services.conversion_custom_variable_service
import google.ads.googleads.v23.services.services.conversion_goal_campaign_config_service
import google.ads.googleads.v23.services.services.conversion_upload_service
import google.ads.googleads.v23.services.services.conversion_value_rule_service
import google.ads.googleads.v23.services.services.conversion_value_rule_set_service
import google.ads.googleads.v23.services.services.custom_audience_service
import google.ads.googleads.v23.services.services.custom_conversion_goal_service
import google.ads.googleads.v23.services.services.custom_interest_service
import google.ads.googleads.v23.services.services.customer_asset_service
import google.ads.googleads.v23.services.services.customer_asset_set_service
import google.ads.googleads.v23.services.services.customer_client_link_service
import google.ads.googleads.v23.services.services.customer_conversion_goal_service
import google.ads.googleads.v23.services.services.customer_customizer_service
import google.ads.googleads.v23.services.services.customer_label_service
import google.ads.googleads.v23.services.services.customer_lifecycle_goal_service
import google.ads.googleads.v23.services.services.customer_manager_link_service
import google.ads.googleads.v23.services.services.customer_negative_criterion_service
import google.ads.googleads.v23.services.services.customer_service
import google.ads.googleads.v23.services.services.customer_sk_ad_network_conversion_value_schema_service
import google.ads.googleads.v23.services.services.customer_user_access_invitation_service
import google.ads.googleads.v23.services.services.customer_user_access_service
import google.ads.googleads.v23.services.services.customizer_attribute_service
import google.ads.googleads.v23.services.services.data_link_service
import google.ads.googleads.v23.services.services.experiment_arm_service
import google.ads.googleads.v23.services.services.experiment_service
import google.ads.googleads.v23.services.services.geo_target_constant_service
import google.ads.googleads.v23.services.services.goal_service
import google.ads.googleads.v23.services.services.google_ads_field_service
import google.ads.googleads.v23.services.services.google_ads_service
import google.ads.googleads.v23.services.services.identity_verification_service
import google.ads.googleads.v23.services.services.incentive_service
import google.ads.googleads.v23.services.services.invoice_service
import google.ads.googleads.v23.services.services.keyword_plan_ad_group_keyword_service
import google.ads.googleads.v23.services.services.keyword_plan_ad_group_service
import google.ads.googleads.v23.services.services.keyword_plan_campaign_keyword_service
import google.ads.googleads.v23.services.services.keyword_plan_campaign_service
import google.ads.googleads.v23.services.services.keyword_plan_idea_service
import google.ads.googleads.v23.services.services.keyword_plan_service
import google.ads.googleads.v23.services.services.keyword_theme_constant_service
import google.ads.googleads.v23.services.services.label_service
import google.ads.googleads.v23.services.services.local_services_lead_service
import google.ads.googleads.v23.services.services.offline_user_data_job_service
import google.ads.googleads.v23.services.services.payments_account_service
import google.ads.googleads.v23.services.services.product_link_invitation_service
import google.ads.googleads.v23.services.services.product_link_service
import google.ads.googleads.v23.services.services.reach_plan_service
import google.ads.googleads.v23.services.services.recommendation_service
import google.ads.googleads.v23.services.services.recommendation_subscription_service
import google.ads.googleads.v23.services.services.remarketing_action_service
import google.ads.googleads.v23.services.services.shareable_preview_service
import google.ads.googleads.v23.services.services.shared_criterion_service
import google.ads.googleads.v23.services.services.shared_set_service
import google.ads.googleads.v23.services.services.smart_campaign_setting_service
import google.ads.googleads.v23.services.services.smart_campaign_suggest_service
import google.ads.googleads.v23.services.services.third_party_app_analytics_link_service
import google.ads.googleads.v23.services.services.travel_asset_suggestion_service
import google.ads.googleads.v23.services.services.user_data_service
import google.ads.googleads.v23.services.services.user_list_customer_type_service
import google.ads.googleads.v23.services.services.user_list_service

# End of autogenerated service imports
# Autogenerated import of latest version
from google.ads.googleads import v23

# End of autogenerated import of latest version
from google.ads.googleads.config import _ConfigDataUnparsed

# Autogenerated version literals
_V20 = Literal["v20"]
_V21 = Literal["v21"]
_V22 = Literal["v22"]
_V23 = Literal["v23"]
_V = _V20 | _V21 | _V22 | _V23
# End of autogenerated version literals

class _EnumGetter:
    # Autogenerated enums
    AccessInvitationStatusEnum: type[
        v23.enums.AccessInvitationStatusEnum.AccessInvitationStatus
    ]
    AccessReasonEnum: type[v23.enums.AccessReasonEnum.AccessReason]
    AccessRoleEnum: type[v23.enums.AccessRoleEnum.AccessRole]
    AccountBudgetProposalStatusEnum: type[
        v23.enums.AccountBudgetProposalStatusEnum.AccountBudgetProposalStatus
    ]
    AccountBudgetProposalTypeEnum: type[
        v23.enums.AccountBudgetProposalTypeEnum.AccountBudgetProposalType
    ]
    AccountBudgetStatusEnum: type[v23.enums.AccountBudgetStatusEnum.AccountBudgetStatus]
    AccountLinkStatusEnum: type[v23.enums.AccountLinkStatusEnum.AccountLinkStatus]
    AdDestinationTypeEnum: type[v23.enums.AdDestinationTypeEnum.AdDestinationType]
    AdFormatTypeEnum: type[v23.enums.AdFormatTypeEnum.AdFormatType]
    AdGroupAdPrimaryStatusEnum: type[
        v23.enums.AdGroupAdPrimaryStatusEnum.AdGroupAdPrimaryStatus
    ]
    AdGroupAdPrimaryStatusReasonEnum: type[
        v23.enums.AdGroupAdPrimaryStatusReasonEnum.AdGroupAdPrimaryStatusReason
    ]
    AdGroupAdRotationModeEnum: type[
        v23.enums.AdGroupAdRotationModeEnum.AdGroupAdRotationMode
    ]
    AdGroupAdStatusEnum: type[v23.enums.AdGroupAdStatusEnum.AdGroupAdStatus]
    AdGroupCriterionApprovalStatusEnum: type[
        v23.enums.AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus
    ]
    AdGroupCriterionPrimaryStatusEnum: type[
        v23.enums.AdGroupCriterionPrimaryStatusEnum.AdGroupCriterionPrimaryStatus
    ]
    AdGroupCriterionPrimaryStatusReasonEnum: type[
        v23.enums.AdGroupCriterionPrimaryStatusReasonEnum.AdGroupCriterionPrimaryStatusReason
    ]
    AdGroupCriterionStatusEnum: type[
        v23.enums.AdGroupCriterionStatusEnum.AdGroupCriterionStatus
    ]
    AdGroupPrimaryStatusEnum: type[
        v23.enums.AdGroupPrimaryStatusEnum.AdGroupPrimaryStatus
    ]
    AdGroupPrimaryStatusReasonEnum: type[
        v23.enums.AdGroupPrimaryStatusReasonEnum.AdGroupPrimaryStatusReason
    ]
    AdGroupStatusEnum: type[v23.enums.AdGroupStatusEnum.AdGroupStatus]
    AdGroupTypeEnum: type[v23.enums.AdGroupTypeEnum.AdGroupType]
    AdNetworkTypeEnum: type[v23.enums.AdNetworkTypeEnum.AdNetworkType]
    AdServingOptimizationStatusEnum: type[
        v23.enums.AdServingOptimizationStatusEnum.AdServingOptimizationStatus
    ]
    AdStrengthActionItemTypeEnum: type[
        v23.enums.AdStrengthActionItemTypeEnum.AdStrengthActionItemType
    ]
    AdStrengthEnum: type[v23.enums.AdStrengthEnum.AdStrength]
    AdSubNetworkTypeEnum: type[v23.enums.AdSubNetworkTypeEnum.AdSubNetworkType]
    AdTypeEnum: type[v23.enums.AdTypeEnum.AdType]
    AdvertisingChannelSubTypeEnum: type[
        v23.enums.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType
    ]
    AdvertisingChannelTypeEnum: type[
        v23.enums.AdvertisingChannelTypeEnum.AdvertisingChannelType
    ]
    AgeRangeTypeEnum: type[v23.enums.AgeRangeTypeEnum.AgeRangeType]
    AndroidPrivacyInteractionTypeEnum: type[
        v23.enums.AndroidPrivacyInteractionTypeEnum.AndroidPrivacyInteractionType
    ]
    AndroidPrivacyNetworkTypeEnum: type[
        v23.enums.AndroidPrivacyNetworkTypeEnum.AndroidPrivacyNetworkType
    ]
    AppBiddingGoalEnum: type[v23.enums.AppBiddingGoalEnum.AppBiddingGoal]
    AppCampaignAppStoreEnum: type[v23.enums.AppCampaignAppStoreEnum.AppCampaignAppStore]
    AppCampaignBiddingStrategyGoalTypeEnum: type[
        v23.enums.AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalType
    ]
    AppPaymentModelTypeEnum: type[v23.enums.AppPaymentModelTypeEnum.AppPaymentModelType]
    AppUrlOperatingSystemTypeEnum: type[
        v23.enums.AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemType
    ]
    ApplicationInstanceEnum: type[v23.enums.ApplicationInstanceEnum.ApplicationInstance]
    AssetAutomationStatusEnum: type[
        v23.enums.AssetAutomationStatusEnum.AssetAutomationStatus
    ]
    AssetAutomationTypeEnum: type[v23.enums.AssetAutomationTypeEnum.AssetAutomationType]
    AssetCoverageVideoAspectRatioRequirementEnum: type[
        v23.enums.AssetCoverageVideoAspectRatioRequirementEnum.AssetCoverageVideoAspectRatioRequirement
    ]
    AssetFieldTypeEnum: type[v23.enums.AssetFieldTypeEnum.AssetFieldType]
    AssetGroupPrimaryStatusEnum: type[
        v23.enums.AssetGroupPrimaryStatusEnum.AssetGroupPrimaryStatus
    ]
    AssetGroupPrimaryStatusReasonEnum: type[
        v23.enums.AssetGroupPrimaryStatusReasonEnum.AssetGroupPrimaryStatusReason
    ]
    AssetGroupSignalApprovalStatusEnum: type[
        v23.enums.AssetGroupSignalApprovalStatusEnum.AssetGroupSignalApprovalStatus
    ]
    AssetGroupStatusEnum: type[v23.enums.AssetGroupStatusEnum.AssetGroupStatus]
    AssetLinkPrimaryStatusEnum: type[
        v23.enums.AssetLinkPrimaryStatusEnum.AssetLinkPrimaryStatus
    ]
    AssetLinkPrimaryStatusReasonEnum: type[
        v23.enums.AssetLinkPrimaryStatusReasonEnum.AssetLinkPrimaryStatusReason
    ]
    AssetLinkStatusEnum: type[v23.enums.AssetLinkStatusEnum.AssetLinkStatus]
    AssetOfflineEvaluationErrorReasonsEnum: type[
        v23.enums.AssetOfflineEvaluationErrorReasonsEnum.AssetOfflineEvaluationErrorReasons
    ]
    AssetOrientationEnum: type[v23.enums.AssetOrientationEnum.AssetOrientation]
    AssetPerformanceLabelEnum: type[
        v23.enums.AssetPerformanceLabelEnum.AssetPerformanceLabel
    ]
    AssetSetAssetStatusEnum: type[v23.enums.AssetSetAssetStatusEnum.AssetSetAssetStatus]
    AssetSetLinkStatusEnum: type[v23.enums.AssetSetLinkStatusEnum.AssetSetLinkStatus]
    AssetSetStatusEnum: type[v23.enums.AssetSetStatusEnum.AssetSetStatus]
    AssetSetTypeEnum: type[v23.enums.AssetSetTypeEnum.AssetSetType]
    AssetSourceEnum: type[v23.enums.AssetSourceEnum.AssetSource]
    AssetTypeEnum: type[v23.enums.AssetTypeEnum.AssetType]
    AsyncActionStatusEnum: type[v23.enums.AsyncActionStatusEnum.AsyncActionStatus]
    AttributionModelEnum: type[v23.enums.AttributionModelEnum.AttributionModel]
    AudienceInsightsDimensionEnum: type[
        v23.enums.AudienceInsightsDimensionEnum.AudienceInsightsDimension
    ]
    AudienceInsightsMarketingObjectiveEnum: type[
        v23.enums.AudienceInsightsMarketingObjectiveEnum.AudienceInsightsMarketingObjective
    ]
    AudienceScopeEnum: type[v23.enums.AudienceScopeEnum.AudienceScope]
    AudienceStatusEnum: type[v23.enums.AudienceStatusEnum.AudienceStatus]
    BatchJobStatusEnum: type[v23.enums.BatchJobStatusEnum.BatchJobStatus]
    BenchmarksMarketingObjectiveEnum: type[
        v23.enums.BenchmarksMarketingObjectiveEnum.BenchmarksMarketingObjective
    ]
    BenchmarksSourceTypeEnum: type[
        v23.enums.BenchmarksSourceTypeEnum.BenchmarksSourceType
    ]
    BidModifierSourceEnum: type[v23.enums.BidModifierSourceEnum.BidModifierSource]
    BiddingSourceEnum: type[v23.enums.BiddingSourceEnum.BiddingSource]
    BiddingStrategyStatusEnum: type[
        v23.enums.BiddingStrategyStatusEnum.BiddingStrategyStatus
    ]
    BiddingStrategySystemStatusEnum: type[
        v23.enums.BiddingStrategySystemStatusEnum.BiddingStrategySystemStatus
    ]
    BiddingStrategyTypeEnum: type[v23.enums.BiddingStrategyTypeEnum.BiddingStrategyType]
    BillingSetupStatusEnum: type[v23.enums.BillingSetupStatusEnum.BillingSetupStatus]
    BrandRequestRejectionReasonEnum: type[
        v23.enums.BrandRequestRejectionReasonEnum.BrandRequestRejectionReason
    ]
    BrandSafetySuitabilityEnum: type[
        v23.enums.BrandSafetySuitabilityEnum.BrandSafetySuitability
    ]
    BrandStateEnum: type[v23.enums.BrandStateEnum.BrandState]
    BudgetCampaignAssociationStatusEnum: type[
        v23.enums.BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus
    ]
    BudgetDeliveryMethodEnum: type[
        v23.enums.BudgetDeliveryMethodEnum.BudgetDeliveryMethod
    ]
    BudgetPeriodEnum: type[v23.enums.BudgetPeriodEnum.BudgetPeriod]
    BudgetStatusEnum: type[v23.enums.BudgetStatusEnum.BudgetStatus]
    BudgetTypeEnum: type[v23.enums.BudgetTypeEnum.BudgetType]
    BusinessMessageCallToActionTypeEnum: type[
        v23.enums.BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType
    ]
    BusinessMessageProviderEnum: type[
        v23.enums.BusinessMessageProviderEnum.BusinessMessageProvider
    ]
    CallConversionReportingStateEnum: type[
        v23.enums.CallConversionReportingStateEnum.CallConversionReportingState
    ]
    CallToActionTypeEnum: type[v23.enums.CallToActionTypeEnum.CallToActionType]
    CallTrackingDisplayLocationEnum: type[
        v23.enums.CallTrackingDisplayLocationEnum.CallTrackingDisplayLocation
    ]
    CallTypeEnum: type[v23.enums.CallTypeEnum.CallType]
    CampaignCriterionStatusEnum: type[
        v23.enums.CampaignCriterionStatusEnum.CampaignCriterionStatus
    ]
    CampaignDraftStatusEnum: type[v23.enums.CampaignDraftStatusEnum.CampaignDraftStatus]
    CampaignExperimentTypeEnum: type[
        v23.enums.CampaignExperimentTypeEnum.CampaignExperimentType
    ]
    CampaignGroupStatusEnum: type[v23.enums.CampaignGroupStatusEnum.CampaignGroupStatus]
    CampaignKeywordMatchTypeEnum: type[
        v23.enums.CampaignKeywordMatchTypeEnum.CampaignKeywordMatchType
    ]
    CampaignPrimaryStatusEnum: type[
        v23.enums.CampaignPrimaryStatusEnum.CampaignPrimaryStatus
    ]
    CampaignPrimaryStatusReasonEnum: type[
        v23.enums.CampaignPrimaryStatusReasonEnum.CampaignPrimaryStatusReason
    ]
    CampaignServingStatusEnum: type[
        v23.enums.CampaignServingStatusEnum.CampaignServingStatus
    ]
    CampaignSharedSetStatusEnum: type[
        v23.enums.CampaignSharedSetStatusEnum.CampaignSharedSetStatus
    ]
    CampaignStatusEnum: type[v23.enums.CampaignStatusEnum.CampaignStatus]
    ChainRelationshipTypeEnum: type[
        v23.enums.ChainRelationshipTypeEnum.ChainRelationshipType
    ]
    ChangeClientTypeEnum: type[v23.enums.ChangeClientTypeEnum.ChangeClientType]
    ChangeEventResourceTypeEnum: type[
        v23.enums.ChangeEventResourceTypeEnum.ChangeEventResourceType
    ]
    ChangeStatusOperationEnum: type[
        v23.enums.ChangeStatusOperationEnum.ChangeStatusOperation
    ]
    ChangeStatusResourceTypeEnum: type[
        v23.enums.ChangeStatusResourceTypeEnum.ChangeStatusResourceType
    ]
    ClickTypeEnum: type[v23.enums.ClickTypeEnum.ClickType]
    CombinedAudienceStatusEnum: type[
        v23.enums.CombinedAudienceStatusEnum.CombinedAudienceStatus
    ]
    ConsentStatusEnum: type[v23.enums.ConsentStatusEnum.ConsentStatus]
    ContentLabelTypeEnum: type[v23.enums.ContentLabelTypeEnum.ContentLabelType]
    ConversionActionCategoryEnum: type[
        v23.enums.ConversionActionCategoryEnum.ConversionActionCategory
    ]
    ConversionActionCountingTypeEnum: type[
        v23.enums.ConversionActionCountingTypeEnum.ConversionActionCountingType
    ]
    ConversionActionStatusEnum: type[
        v23.enums.ConversionActionStatusEnum.ConversionActionStatus
    ]
    ConversionActionTypeEnum: type[
        v23.enums.ConversionActionTypeEnum.ConversionActionType
    ]
    ConversionAdjustmentTypeEnum: type[
        v23.enums.ConversionAdjustmentTypeEnum.ConversionAdjustmentType
    ]
    ConversionAttributionEventTypeEnum: type[
        v23.enums.ConversionAttributionEventTypeEnum.ConversionAttributionEventType
    ]
    ConversionCustomVariableStatusEnum: type[
        v23.enums.ConversionCustomVariableStatusEnum.ConversionCustomVariableStatus
    ]
    ConversionCustomerTypeEnum: type[
        v23.enums.ConversionCustomerTypeEnum.ConversionCustomerType
    ]
    ConversionEnvironmentEnum: type[
        v23.enums.ConversionEnvironmentEnum.ConversionEnvironment
    ]
    ConversionLagBucketEnum: type[v23.enums.ConversionLagBucketEnum.ConversionLagBucket]
    ConversionOrAdjustmentLagBucketEnum: type[
        v23.enums.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket
    ]
    ConversionOriginEnum: type[v23.enums.ConversionOriginEnum.ConversionOrigin]
    ConversionTrackingStatusEnum: type[
        v23.enums.ConversionTrackingStatusEnum.ConversionTrackingStatus
    ]
    ConversionValueRulePrimaryDimensionEnum: type[
        v23.enums.ConversionValueRulePrimaryDimensionEnum.ConversionValueRulePrimaryDimension
    ]
    ConversionValueRuleSetStatusEnum: type[
        v23.enums.ConversionValueRuleSetStatusEnum.ConversionValueRuleSetStatus
    ]
    ConversionValueRuleStatusEnum: type[
        v23.enums.ConversionValueRuleStatusEnum.ConversionValueRuleStatus
    ]
    ConvertingUserPriorEngagementTypeAndLtvBucketEnum: type[
        v23.enums.ConvertingUserPriorEngagementTypeAndLtvBucketEnum.ConvertingUserPriorEngagementTypeAndLtvBucket
    ]
    CriterionCategoryChannelAvailabilityModeEnum: type[
        v23.enums.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode
    ]
    CriterionCategoryLocaleAvailabilityModeEnum: type[
        v23.enums.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode
    ]
    CriterionSystemServingStatusEnum: type[
        v23.enums.CriterionSystemServingStatusEnum.CriterionSystemServingStatus
    ]
    CriterionTypeEnum: type[v23.enums.CriterionTypeEnum.CriterionType]
    CustomAudienceMemberTypeEnum: type[
        v23.enums.CustomAudienceMemberTypeEnum.CustomAudienceMemberType
    ]
    CustomAudienceStatusEnum: type[
        v23.enums.CustomAudienceStatusEnum.CustomAudienceStatus
    ]
    CustomAudienceTypeEnum: type[v23.enums.CustomAudienceTypeEnum.CustomAudienceType]
    CustomConversionGoalStatusEnum: type[
        v23.enums.CustomConversionGoalStatusEnum.CustomConversionGoalStatus
    ]
    CustomInterestMemberTypeEnum: type[
        v23.enums.CustomInterestMemberTypeEnum.CustomInterestMemberType
    ]
    CustomInterestStatusEnum: type[
        v23.enums.CustomInterestStatusEnum.CustomInterestStatus
    ]
    CustomInterestTypeEnum: type[v23.enums.CustomInterestTypeEnum.CustomInterestType]
    CustomerAcquisitionOptimizationModeEnum: type[
        v23.enums.CustomerAcquisitionOptimizationModeEnum.CustomerAcquisitionOptimizationMode
    ]
    CustomerLifecycleOptimizationModeEnum: type[
        v23.enums.CustomerLifecycleOptimizationModeEnum.CustomerLifecycleOptimizationMode
    ]
    CustomerMatchUploadKeyTypeEnum: type[
        v23.enums.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType
    ]
    CustomerPayPerConversionEligibilityFailureReasonEnum: type[
        v23.enums.CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReason
    ]
    CustomerStatusEnum: type[v23.enums.CustomerStatusEnum.CustomerStatus]
    CustomizerAttributeStatusEnum: type[
        v23.enums.CustomizerAttributeStatusEnum.CustomizerAttributeStatus
    ]
    CustomizerAttributeTypeEnum: type[
        v23.enums.CustomizerAttributeTypeEnum.CustomizerAttributeType
    ]
    CustomizerValueStatusEnum: type[
        v23.enums.CustomizerValueStatusEnum.CustomizerValueStatus
    ]
    DataDrivenModelStatusEnum: type[
        v23.enums.DataDrivenModelStatusEnum.DataDrivenModelStatus
    ]
    DataLinkStatusEnum: type[v23.enums.DataLinkStatusEnum.DataLinkStatus]
    DataLinkTypeEnum: type[v23.enums.DataLinkTypeEnum.DataLinkType]
    DayOfWeekEnum: type[v23.enums.DayOfWeekEnum.DayOfWeek]
    DemandGenChannelConfigEnum: type[
        v23.enums.DemandGenChannelConfigEnum.DemandGenChannelConfig
    ]
    DemandGenChannelStrategyEnum: type[
        v23.enums.DemandGenChannelStrategyEnum.DemandGenChannelStrategy
    ]
    DeviceEnum: type[v23.enums.DeviceEnum.Device]
    DisplayAdFormatSettingEnum: type[
        v23.enums.DisplayAdFormatSettingEnum.DisplayAdFormatSetting
    ]
    DisplayUploadProductTypeEnum: type[
        v23.enums.DisplayUploadProductTypeEnum.DisplayUploadProductType
    ]
    DistanceBucketEnum: type[v23.enums.DistanceBucketEnum.DistanceBucket]
    EuPoliticalAdvertisingStatusEnum: type[
        v23.enums.EuPoliticalAdvertisingStatusEnum.EuPoliticalAdvertisingStatus
    ]
    ExperimentMetricDirectionEnum: type[
        v23.enums.ExperimentMetricDirectionEnum.ExperimentMetricDirection
    ]
    ExperimentMetricEnum: type[v23.enums.ExperimentMetricEnum.ExperimentMetric]
    ExperimentStatusEnum: type[v23.enums.ExperimentStatusEnum.ExperimentStatus]
    ExperimentTypeEnum: type[v23.enums.ExperimentTypeEnum.ExperimentType]
    ExternalConversionSourceEnum: type[
        v23.enums.ExternalConversionSourceEnum.ExternalConversionSource
    ]
    FixedCpmGoalEnum: type[v23.enums.FixedCpmGoalEnum.FixedCpmGoal]
    FixedCpmTargetFrequencyTimeUnitEnum: type[
        v23.enums.FixedCpmTargetFrequencyTimeUnitEnum.FixedCpmTargetFrequencyTimeUnit
    ]
    FrequencyCapEventTypeEnum: type[
        v23.enums.FrequencyCapEventTypeEnum.FrequencyCapEventType
    ]
    FrequencyCapLevelEnum: type[v23.enums.FrequencyCapLevelEnum.FrequencyCapLevel]
    FrequencyCapTimeUnitEnum: type[
        v23.enums.FrequencyCapTimeUnitEnum.FrequencyCapTimeUnit
    ]
    GenderTypeEnum: type[v23.enums.GenderTypeEnum.GenderType]
    GeoTargetConstantStatusEnum: type[
        v23.enums.GeoTargetConstantStatusEnum.GeoTargetConstantStatus
    ]
    GeoTargetingTypeEnum: type[v23.enums.GeoTargetingTypeEnum.GeoTargetingType]
    GoalConfigLevelEnum: type[v23.enums.GoalConfigLevelEnum.GoalConfigLevel]
    GoalOptimizationEligibilityEnum: type[
        v23.enums.GoalOptimizationEligibilityEnum.GoalOptimizationEligibility
    ]
    GoalTypeEnum: type[v23.enums.GoalTypeEnum.GoalType]
    GoogleAdsFieldCategoryEnum: type[
        v23.enums.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory
    ]
    GoogleAdsFieldDataTypeEnum: type[
        v23.enums.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType
    ]
    GoogleVoiceCallStatusEnum: type[
        v23.enums.GoogleVoiceCallStatusEnum.GoogleVoiceCallStatus
    ]
    HotelAssetSuggestionStatusEnum: type[
        v23.enums.HotelAssetSuggestionStatusEnum.HotelAssetSuggestionStatus
    ]
    HotelDateSelectionTypeEnum: type[
        v23.enums.HotelDateSelectionTypeEnum.HotelDateSelectionType
    ]
    HotelPriceBucketEnum: type[v23.enums.HotelPriceBucketEnum.HotelPriceBucket]
    HotelRateTypeEnum: type[v23.enums.HotelRateTypeEnum.HotelRateType]
    HotelReconciliationStatusEnum: type[
        v23.enums.HotelReconciliationStatusEnum.HotelReconciliationStatus
    ]
    IdentityVerificationProgramEnum: type[
        v23.enums.IdentityVerificationProgramEnum.IdentityVerificationProgram
    ]
    IdentityVerificationProgramStatusEnum: type[
        v23.enums.IdentityVerificationProgramStatusEnum.IdentityVerificationProgramStatus
    ]
    IncentiveStateEnum: type[v23.enums.IncentiveStateEnum.IncentiveState]
    IncomeRangeTypeEnum: type[v23.enums.IncomeRangeTypeEnum.IncomeRangeType]
    InsightsKnowledgeGraphEntityCapabilitiesEnum: type[
        v23.enums.InsightsKnowledgeGraphEntityCapabilitiesEnum.InsightsKnowledgeGraphEntityCapabilities
    ]
    InsightsTrendEnum: type[v23.enums.InsightsTrendEnum.InsightsTrend]
    InteractionEventTypeEnum: type[
        v23.enums.InteractionEventTypeEnum.InteractionEventType
    ]
    InteractionTypeEnum: type[v23.enums.InteractionTypeEnum.InteractionType]
    InvoiceTypeEnum: type[v23.enums.InvoiceTypeEnum.InvoiceType]
    KeywordMatchTypeEnum: type[v23.enums.KeywordMatchTypeEnum.KeywordMatchType]
    KeywordPlanAggregateMetricTypeEnum: type[
        v23.enums.KeywordPlanAggregateMetricTypeEnum.KeywordPlanAggregateMetricType
    ]
    KeywordPlanCompetitionLevelEnum: type[
        v23.enums.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel
    ]
    KeywordPlanConceptGroupTypeEnum: type[
        v23.enums.KeywordPlanConceptGroupTypeEnum.KeywordPlanConceptGroupType
    ]
    KeywordPlanForecastIntervalEnum: type[
        v23.enums.KeywordPlanForecastIntervalEnum.KeywordPlanForecastInterval
    ]
    KeywordPlanKeywordAnnotationEnum: type[
        v23.enums.KeywordPlanKeywordAnnotationEnum.KeywordPlanKeywordAnnotation
    ]
    KeywordPlanNetworkEnum: type[v23.enums.KeywordPlanNetworkEnum.KeywordPlanNetwork]
    LabelStatusEnum: type[v23.enums.LabelStatusEnum.LabelStatus]
    LandingPageSourceEnum: type[v23.enums.LandingPageSourceEnum.LandingPageSource]
    LeadFormCallToActionTypeEnum: type[
        v23.enums.LeadFormCallToActionTypeEnum.LeadFormCallToActionType
    ]
    LeadFormDesiredIntentEnum: type[
        v23.enums.LeadFormDesiredIntentEnum.LeadFormDesiredIntent
    ]
    LeadFormFieldUserInputTypeEnum: type[
        v23.enums.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType
    ]
    LeadFormPostSubmitCallToActionTypeEnum: type[
        v23.enums.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType
    ]
    LegacyAppInstallAdAppStoreEnum: type[
        v23.enums.LegacyAppInstallAdAppStoreEnum.LegacyAppInstallAdAppStore
    ]
    LinkedAccountTypeEnum: type[v23.enums.LinkedAccountTypeEnum.LinkedAccountType]
    LinkedProductTypeEnum: type[v23.enums.LinkedProductTypeEnum.LinkedProductType]
    ListingGroupFilterCustomAttributeIndexEnum: type[
        v23.enums.ListingGroupFilterCustomAttributeIndexEnum.ListingGroupFilterCustomAttributeIndex
    ]
    ListingGroupFilterListingSourceEnum: type[
        v23.enums.ListingGroupFilterListingSourceEnum.ListingGroupFilterListingSource
    ]
    ListingGroupFilterProductCategoryLevelEnum: type[
        v23.enums.ListingGroupFilterProductCategoryLevelEnum.ListingGroupFilterProductCategoryLevel
    ]
    ListingGroupFilterProductChannelEnum: type[
        v23.enums.ListingGroupFilterProductChannelEnum.ListingGroupFilterProductChannel
    ]
    ListingGroupFilterProductConditionEnum: type[
        v23.enums.ListingGroupFilterProductConditionEnum.ListingGroupFilterProductCondition
    ]
    ListingGroupFilterProductTypeLevelEnum: type[
        v23.enums.ListingGroupFilterProductTypeLevelEnum.ListingGroupFilterProductTypeLevel
    ]
    ListingGroupFilterTypeEnum: type[
        v23.enums.ListingGroupFilterTypeEnum.ListingGroupFilterType
    ]
    ListingGroupTypeEnum: type[v23.enums.ListingGroupTypeEnum.ListingGroupType]
    ListingTypeEnum: type[v23.enums.ListingTypeEnum.ListingType]
    LocalServicesBusinessRegistrationCheckRejectionReasonEnum: type[
        v23.enums.LocalServicesBusinessRegistrationCheckRejectionReasonEnum.LocalServicesBusinessRegistrationCheckRejectionReason
    ]
    LocalServicesBusinessRegistrationTypeEnum: type[
        v23.enums.LocalServicesBusinessRegistrationTypeEnum.LocalServicesBusinessRegistrationType
    ]
    LocalServicesCreditStateEnum: type[
        v23.enums.LocalServicesCreditStateEnum.CreditState
    ]
    LocalServicesEmployeeStatusEnum: type[
        v23.enums.LocalServicesEmployeeStatusEnum.LocalServicesEmployeeStatus
    ]
    LocalServicesEmployeeTypeEnum: type[
        v23.enums.LocalServicesEmployeeTypeEnum.LocalServicesEmployeeType
    ]
    LocalServicesInsuranceRejectionReasonEnum: type[
        v23.enums.LocalServicesInsuranceRejectionReasonEnum.LocalServicesInsuranceRejectionReason
    ]
    LocalServicesLeadConversationTypeEnum: type[
        v23.enums.LocalServicesLeadConversationTypeEnum.ConversationType
    ]
    LocalServicesLeadCreditIssuanceDecisionEnum: type[
        v23.enums.LocalServicesLeadCreditIssuanceDecisionEnum.CreditIssuanceDecision
    ]
    LocalServicesLeadStatusEnum: type[v23.enums.LocalServicesLeadStatusEnum.LeadStatus]
    LocalServicesLeadSurveyAnswerEnum: type[
        v23.enums.LocalServicesLeadSurveyAnswerEnum.SurveyAnswer
    ]
    LocalServicesLeadSurveyDissatisfiedReasonEnum: type[
        v23.enums.LocalServicesLeadSurveyDissatisfiedReasonEnum.SurveyDissatisfiedReason
    ]
    LocalServicesLeadSurveySatisfiedReasonEnum: type[
        v23.enums.LocalServicesLeadSurveySatisfiedReasonEnum.SurveySatisfiedReason
    ]
    LocalServicesLeadTypeEnum: type[v23.enums.LocalServicesLeadTypeEnum.LeadType]
    LocalServicesLicenseRejectionReasonEnum: type[
        v23.enums.LocalServicesLicenseRejectionReasonEnum.LocalServicesLicenseRejectionReason
    ]
    LocalServicesParticipantTypeEnum: type[
        v23.enums.LocalServicesParticipantTypeEnum.ParticipantType
    ]
    LocalServicesVerificationArtifactStatusEnum: type[
        v23.enums.LocalServicesVerificationArtifactStatusEnum.LocalServicesVerificationArtifactStatus
    ]
    LocalServicesVerificationArtifactTypeEnum: type[
        v23.enums.LocalServicesVerificationArtifactTypeEnum.LocalServicesVerificationArtifactType
    ]
    LocalServicesVerificationStatusEnum: type[
        v23.enums.LocalServicesVerificationStatusEnum.LocalServicesVerificationStatus
    ]
    LocationGroupRadiusUnitsEnum: type[
        v23.enums.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits
    ]
    LocationOwnershipTypeEnum: type[
        v23.enums.LocationOwnershipTypeEnum.LocationOwnershipType
    ]
    LocationSourceTypeEnum: type[v23.enums.LocationSourceTypeEnum.LocationSourceType]
    LocationStringFilterTypeEnum: type[
        v23.enums.LocationStringFilterTypeEnum.LocationStringFilterType
    ]
    LookalikeExpansionLevelEnum: type[
        v23.enums.LookalikeExpansionLevelEnum.LookalikeExpansionLevel
    ]
    ManagerLinkStatusEnum: type[v23.enums.ManagerLinkStatusEnum.ManagerLinkStatus]
    MatchTypeEnum: type[v23.enums.MatchTypeEnum.MatchType]
    MediaTypeEnum: type[v23.enums.MediaTypeEnum.MediaType]
    MimeTypeEnum: type[v23.enums.MimeTypeEnum.MimeType]
    MinuteOfHourEnum: type[v23.enums.MinuteOfHourEnum.MinuteOfHour]
    MobileAppVendorEnum: type[v23.enums.MobileAppVendorEnum.MobileAppVendor]
    MobileDeviceTypeEnum: type[v23.enums.MobileDeviceTypeEnum.MobileDeviceType]
    MonthOfYearEnum: type[v23.enums.MonthOfYearEnum.MonthOfYear]
    NegativeGeoTargetTypeEnum: type[
        v23.enums.NegativeGeoTargetTypeEnum.NegativeGeoTargetType
    ]
    NonSkippableMaxDurationEnum: type[
        v23.enums.NonSkippableMaxDurationEnum.NonSkippableMaxDuration
    ]
    NonSkippableMinDurationEnum: type[
        v23.enums.NonSkippableMinDurationEnum.NonSkippableMinDuration
    ]
    OfflineConversionDiagnosticStatusEnum: type[
        v23.enums.OfflineConversionDiagnosticStatusEnum.OfflineConversionDiagnosticStatus
    ]
    OfflineEventUploadClientEnum: type[
        v23.enums.OfflineEventUploadClientEnum.OfflineEventUploadClient
    ]
    OfflineUserDataJobFailureReasonEnum: type[
        v23.enums.OfflineUserDataJobFailureReasonEnum.OfflineUserDataJobFailureReason
    ]
    OfflineUserDataJobMatchRateRangeEnum: type[
        v23.enums.OfflineUserDataJobMatchRateRangeEnum.OfflineUserDataJobMatchRateRange
    ]
    OfflineUserDataJobStatusEnum: type[
        v23.enums.OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus
    ]
    OfflineUserDataJobTypeEnum: type[
        v23.enums.OfflineUserDataJobTypeEnum.OfflineUserDataJobType
    ]
    OperatingSystemVersionOperatorTypeEnum: type[
        v23.enums.OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType
    ]
    OptimizationGoalTypeEnum: type[
        v23.enums.OptimizationGoalTypeEnum.OptimizationGoalType
    ]
    ParentalStatusTypeEnum: type[v23.enums.ParentalStatusTypeEnum.ParentalStatusType]
    PaymentModeEnum: type[v23.enums.PaymentModeEnum.PaymentMode]
    PerformanceMaxUpgradeStatusEnum: type[
        v23.enums.PerformanceMaxUpgradeStatusEnum.PerformanceMaxUpgradeStatus
    ]
    PlacementTypeEnum: type[v23.enums.PlacementTypeEnum.PlacementType]
    PolicyApprovalStatusEnum: type[
        v23.enums.PolicyApprovalStatusEnum.PolicyApprovalStatus
    ]
    PolicyReviewStatusEnum: type[v23.enums.PolicyReviewStatusEnum.PolicyReviewStatus]
    PolicyTopicEntryTypeEnum: type[
        v23.enums.PolicyTopicEntryTypeEnum.PolicyTopicEntryType
    ]
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum: type[
        v23.enums.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType
    ]
    PolicyTopicEvidenceDestinationNotWorkingDeviceEnum: type[
        v23.enums.PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice
    ]
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum: type[
        v23.enums.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    ]
    PositiveGeoTargetTypeEnum: type[
        v23.enums.PositiveGeoTargetTypeEnum.PositiveGeoTargetType
    ]
    PriceExtensionPriceQualifierEnum: type[
        v23.enums.PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier
    ]
    PriceExtensionPriceUnitEnum: type[
        v23.enums.PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit
    ]
    PriceExtensionTypeEnum: type[v23.enums.PriceExtensionTypeEnum.PriceExtensionType]
    ProductAvailabilityEnum: type[v23.enums.ProductAvailabilityEnum.ProductAvailability]
    ProductCategoryLevelEnum: type[
        v23.enums.ProductCategoryLevelEnum.ProductCategoryLevel
    ]
    ProductCategoryStateEnum: type[
        v23.enums.ProductCategoryStateEnum.ProductCategoryState
    ]
    ProductChannelEnum: type[v23.enums.ProductChannelEnum.ProductChannel]
    ProductChannelExclusivityEnum: type[
        v23.enums.ProductChannelExclusivityEnum.ProductChannelExclusivity
    ]
    ProductConditionEnum: type[v23.enums.ProductConditionEnum.ProductCondition]
    ProductCustomAttributeIndexEnum: type[
        v23.enums.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex
    ]
    ProductIssueSeverityEnum: type[
        v23.enums.ProductIssueSeverityEnum.ProductIssueSeverity
    ]
    ProductLinkInvitationStatusEnum: type[
        v23.enums.ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus
    ]
    ProductStatusEnum: type[v23.enums.ProductStatusEnum.ProductStatus]
    ProductTypeLevelEnum: type[v23.enums.ProductTypeLevelEnum.ProductTypeLevel]
    PromotionBarcodeTypeEnum: type[
        v23.enums.PromotionBarcodeTypeEnum.PromotionBarcodeType
    ]
    PromotionExtensionDiscountModifierEnum: type[
        v23.enums.PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier
    ]
    PromotionExtensionOccasionEnum: type[
        v23.enums.PromotionExtensionOccasionEnum.PromotionExtensionOccasion
    ]
    ProximityRadiusUnitsEnum: type[
        v23.enums.ProximityRadiusUnitsEnum.ProximityRadiusUnits
    ]
    QualityScoreBucketEnum: type[v23.enums.QualityScoreBucketEnum.QualityScoreBucket]
    ReachPlanAgeRangeEnum: type[v23.enums.ReachPlanAgeRangeEnum.ReachPlanAgeRange]
    ReachPlanConversionRateModelEnum: type[
        v23.enums.ReachPlanConversionRateModelEnum.ReachPlanConversionRateModel
    ]
    ReachPlanNetworkEnum: type[v23.enums.ReachPlanNetworkEnum.ReachPlanNetwork]
    ReachPlanPlannableUserListStatusEnum: type[
        v23.enums.ReachPlanPlannableUserListStatusEnum.ReachPlanPlannableUserListStatus
    ]
    ReachPlanSurfaceEnum: type[v23.enums.ReachPlanSurfaceEnum.ReachPlanSurface]
    RecommendationSubscriptionStatusEnum: type[
        v23.enums.RecommendationSubscriptionStatusEnum.RecommendationSubscriptionStatus
    ]
    RecommendationTypeEnum: type[v23.enums.RecommendationTypeEnum.RecommendationType]
    RegulatoryFeeTypeEnum: type[v23.enums.RegulatoryFeeTypeEnum.RegulatoryFeeType]
    ResourceChangeOperationEnum: type[
        v23.enums.ResourceChangeOperationEnum.ResourceChangeOperation
    ]
    ResourceLimitTypeEnum: type[v23.enums.ResourceLimitTypeEnum.ResourceLimitType]
    ResponseContentTypeEnum: type[v23.enums.ResponseContentTypeEnum.ResponseContentType]
    SearchEngineResultsPageTypeEnum: type[
        v23.enums.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType
    ]
    SearchTermMatchSourceEnum: type[
        v23.enums.SearchTermMatchSourceEnum.SearchTermMatchSource
    ]
    SearchTermMatchTypeEnum: type[v23.enums.SearchTermMatchTypeEnum.SearchTermMatchType]
    SearchTermTargetingStatusEnum: type[
        v23.enums.SearchTermTargetingStatusEnum.SearchTermTargetingStatus
    ]
    SeasonalityEventScopeEnum: type[
        v23.enums.SeasonalityEventScopeEnum.SeasonalityEventScope
    ]
    SeasonalityEventStatusEnum: type[
        v23.enums.SeasonalityEventStatusEnum.SeasonalityEventStatus
    ]
    ServedAssetFieldTypeEnum: type[
        v23.enums.ServedAssetFieldTypeEnum.ServedAssetFieldType
    ]
    SharedSetStatusEnum: type[v23.enums.SharedSetStatusEnum.SharedSetStatus]
    SharedSetTypeEnum: type[v23.enums.SharedSetTypeEnum.SharedSetType]
    ShoppingAddProductsToCampaignRecommendationEnum: type[
        v23.enums.ShoppingAddProductsToCampaignRecommendationEnum.Reason
    ]
    SimulationModificationMethodEnum: type[
        v23.enums.SimulationModificationMethodEnum.SimulationModificationMethod
    ]
    SimulationTypeEnum: type[v23.enums.SimulationTypeEnum.SimulationType]
    SkAdNetworkAdEventTypeEnum: type[
        v23.enums.SkAdNetworkAdEventTypeEnum.SkAdNetworkAdEventType
    ]
    SkAdNetworkAttributionCreditEnum: type[
        v23.enums.SkAdNetworkAttributionCreditEnum.SkAdNetworkAttributionCredit
    ]
    SkAdNetworkCoarseConversionValueEnum: type[
        v23.enums.SkAdNetworkCoarseConversionValueEnum.SkAdNetworkCoarseConversionValue
    ]
    SkAdNetworkSourceTypeEnum: type[
        v23.enums.SkAdNetworkSourceTypeEnum.SkAdNetworkSourceType
    ]
    SkAdNetworkUserTypeEnum: type[v23.enums.SkAdNetworkUserTypeEnum.SkAdNetworkUserType]
    SlotEnum: type[v23.enums.SlotEnum.Slot]
    SmartCampaignNotEligibleReasonEnum: type[
        v23.enums.SmartCampaignNotEligibleReasonEnum.SmartCampaignNotEligibleReason
    ]
    SmartCampaignStatusEnum: type[v23.enums.SmartCampaignStatusEnum.SmartCampaignStatus]
    SpendingLimitTypeEnum: type[v23.enums.SpendingLimitTypeEnum.SpendingLimitType]
    SummaryRowSettingEnum: type[v23.enums.SummaryRowSettingEnum.SummaryRowSetting]
    SystemManagedResourceSourceEnum: type[
        v23.enums.SystemManagedResourceSourceEnum.SystemManagedResourceSource
    ]
    TargetCpaOptInRecommendationGoalEnum: type[
        v23.enums.TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoal
    ]
    TargetFrequencyTimeUnitEnum: type[
        v23.enums.TargetFrequencyTimeUnitEnum.TargetFrequencyTimeUnit
    ]
    TargetImpressionShareLocationEnum: type[
        v23.enums.TargetImpressionShareLocationEnum.TargetImpressionShareLocation
    ]
    TargetingDimensionEnum: type[v23.enums.TargetingDimensionEnum.TargetingDimension]
    ThirdPartyBrandLiftIntegrationPartnerEnum: type[
        v23.enums.ThirdPartyBrandLiftIntegrationPartnerEnum.ThirdPartyBrandLiftIntegrationPartner
    ]
    ThirdPartyBrandSafetyIntegrationPartnerEnum: type[
        v23.enums.ThirdPartyBrandSafetyIntegrationPartnerEnum.ThirdPartyBrandSafetyIntegrationPartner
    ]
    ThirdPartyReachIntegrationPartnerEnum: type[
        v23.enums.ThirdPartyReachIntegrationPartnerEnum.ThirdPartyReachIntegrationPartner
    ]
    ThirdPartyViewabilityIntegrationPartnerEnum: type[
        v23.enums.ThirdPartyViewabilityIntegrationPartnerEnum.ThirdPartyViewabilityIntegrationPartner
    ]
    TimeTypeEnum: type[v23.enums.TimeTypeEnum.TimeType]
    TrackingCodePageFormatEnum: type[
        v23.enums.TrackingCodePageFormatEnum.TrackingCodePageFormat
    ]
    TrackingCodeTypeEnum: type[v23.enums.TrackingCodeTypeEnum.TrackingCodeType]
    UnitOfMeasureEnum: type[v23.enums.UnitOfMeasureEnum.UnitOfMeasure]
    UserIdentifierSourceEnum: type[
        v23.enums.UserIdentifierSourceEnum.UserIdentifierSource
    ]
    UserInterestTaxonomyTypeEnum: type[
        v23.enums.UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType
    ]
    UserListAccessStatusEnum: type[
        v23.enums.UserListAccessStatusEnum.UserListAccessStatus
    ]
    UserListClosingReasonEnum: type[
        v23.enums.UserListClosingReasonEnum.UserListClosingReason
    ]
    UserListCrmDataSourceTypeEnum: type[
        v23.enums.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType
    ]
    UserListCustomerTypeCategoryEnum: type[
        v23.enums.UserListCustomerTypeCategoryEnum.UserListCustomerTypeCategory
    ]
    UserListDateRuleItemOperatorEnum: type[
        v23.enums.UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator
    ]
    UserListFlexibleRuleOperatorEnum: type[
        v23.enums.UserListFlexibleRuleOperatorEnum.UserListFlexibleRuleOperator
    ]
    UserListLogicalRuleOperatorEnum: type[
        v23.enums.UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator
    ]
    UserListMembershipStatusEnum: type[
        v23.enums.UserListMembershipStatusEnum.UserListMembershipStatus
    ]
    UserListNumberRuleItemOperatorEnum: type[
        v23.enums.UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator
    ]
    UserListPrepopulationStatusEnum: type[
        v23.enums.UserListPrepopulationStatusEnum.UserListPrepopulationStatus
    ]
    UserListRuleTypeEnum: type[v23.enums.UserListRuleTypeEnum.UserListRuleType]
    UserListSizeRangeEnum: type[v23.enums.UserListSizeRangeEnum.UserListSizeRange]
    UserListStringRuleItemOperatorEnum: type[
        v23.enums.UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator
    ]
    UserListTypeEnum: type[v23.enums.UserListTypeEnum.UserListType]
    ValueRuleDeviceTypeEnum: type[v23.enums.ValueRuleDeviceTypeEnum.ValueRuleDeviceType]
    ValueRuleGeoLocationMatchTypeEnum: type[
        v23.enums.ValueRuleGeoLocationMatchTypeEnum.ValueRuleGeoLocationMatchType
    ]
    ValueRuleOperationEnum: type[v23.enums.ValueRuleOperationEnum.ValueRuleOperation]
    ValueRuleSetAttachmentTypeEnum: type[
        v23.enums.ValueRuleSetAttachmentTypeEnum.ValueRuleSetAttachmentType
    ]
    ValueRuleSetDimensionEnum: type[
        v23.enums.ValueRuleSetDimensionEnum.ValueRuleSetDimension
    ]
    VanityPharmaDisplayUrlModeEnum: type[
        v23.enums.VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlMode
    ]
    VanityPharmaTextEnum: type[v23.enums.VanityPharmaTextEnum.VanityPharmaText]
    VerticalAdsItemVerticalTypeEnum: type[
        v23.enums.VerticalAdsItemVerticalTypeEnum.VerticalAdsItemVerticalType
    ]
    VideoAdFormatRestrictionEnum: type[
        v23.enums.VideoAdFormatRestrictionEnum.VideoAdFormatRestriction
    ]
    VideoAdSequenceInteractionTypeEnum: type[
        v23.enums.VideoAdSequenceInteractionTypeEnum.VideoAdSequenceInteractionType
    ]
    VideoAdSequenceMinimumDurationEnum: type[
        v23.enums.VideoAdSequenceMinimumDurationEnum.VideoAdSequenceMinimumDuration
    ]
    VideoThumbnailEnum: type[v23.enums.VideoThumbnailEnum.VideoThumbnail]
    WebpageConditionOperandEnum: type[
        v23.enums.WebpageConditionOperandEnum.WebpageConditionOperand
    ]
    WebpageConditionOperatorEnum: type[
        v23.enums.WebpageConditionOperatorEnum.WebpageConditionOperator
    ]
    YouTubeVideoPropertyEnum: type[
        v23.enums.YouTubeVideoPropertyEnum.YouTubeVideoProperty
    ]
    # End of autogenerated enums

class GoogleAdsClient:
    credentials: Credentials
    developer_token: str
    endpoint: str | None
    login_customer_id: str | None
    linked_customer_id: str | None
    version: str | None
    http_proxy: str | None
    use_proto_plus: bool
    enums: _EnumGetter
    gaada: str | None
    @classmethod
    def copy_from(
        cls,
        destination: proto.Message | Message,
        origin: proto.Message | Message,
    ) -> None: ...
    @classmethod
    def load_from_env(cls, version: str | None = None) -> GoogleAdsClient: ...
    @classmethod
    def load_from_string(
        cls, yaml_str: str, version: str | None = None
    ) -> GoogleAdsClient: ...
    @classmethod
    def load_from_storage(
        cls, path: str | None = None, version: str | None = None
    ) -> GoogleAdsClient: ...
    @classmethod
    def load_from_dict(
        cls, config_dict: _ConfigDataUnparsed, version: str | None = None
    ) -> GoogleAdsClient: ...
    def __init__(
        self,
        credentials: Credentials,
        developer_token: str,
        endpoint: str | None = None,
        login_customer_id: str | None = None,
        logging_config: dict[Any, Any] | None = None,
        linked_customer_id: str | None = None,
        version: str | None = None,
        http_proxy: str | None = None,
        use_proto_plus: bool = False,
        use_cloud_org_for_api_access: bool | None = None,
        gaada: str | None = None,
    ) -> None: ...
    # Autogenerated get_type overload
    def get_type(cls, name: str, version: _V = "v23") -> Any: ...
    # End of autogenerated get_type overload
    # Autogenerated service overloads
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.account_budget_proposal_service.AccountBudgetProposalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.account_budget_proposal_service.AccountBudgetProposalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.account_link_service.AccountLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.account_link_service.AccountLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_ad_service.AdGroupAdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_ad_service.AdGroupAdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_asset_service.AdGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_asset_service.AdGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_service.AdGroupCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_criterion_service.AdGroupCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_customizer_service.AdGroupCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_customizer_service.AdGroupCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_label_service.AdGroupLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_label_service.AdGroupLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupService"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.ad_group_service.AdGroupServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AdGroupServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_group_service.AdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_parameter_service.AdParameterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_parameter_service.AdParameterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_service.AdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.ad_service.AdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_asset_service.AssetGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_asset_service.AssetGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_service.AssetGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_service.AssetGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_signal_service.AssetGroupSignalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_group_signal_service.AssetGroupSignalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetService"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.asset_service.AssetServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetServiceAsync"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.asset_service.AssetServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_set_asset_service.AssetSetAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_set_asset_service.AssetSetAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_set_service.AssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.asset_set_service.AssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.audience_insights_service.AudienceInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.audience_insights_service.AudienceInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.audience_service.AudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.audience_service.AudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.batch_job_service.BatchJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.batch_job_service.BatchJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_strategy_service.BiddingStrategyServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.bidding_strategy_service.BiddingStrategyServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.billing_setup_service.BillingSetupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.billing_setup_service.BillingSetupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.brand_suggestion_service.BrandSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.brand_suggestion_service.BrandSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_asset_service.CampaignAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_asset_service.CampaignAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_asset_set_service.CampaignAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_asset_set_service.CampaignAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_budget_service.CampaignBudgetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_budget_service.CampaignBudgetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_criterion_service.CampaignCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_criterion_service.CampaignCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_customizer_service.CampaignCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_customizer_service.CampaignCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_draft_service.CampaignDraftServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_draft_service.CampaignDraftServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_group_service.CampaignGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_group_service.CampaignGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_label_service.CampaignLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_label_service.CampaignLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_service.CampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_service.CampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_shared_set_service.CampaignSharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.campaign_shared_set_service.CampaignSharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.content_creator_insights_service.ContentCreatorInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.content_creator_insights_service.ContentCreatorInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_action_service.ConversionActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_action_service.ConversionActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_upload_service.ConversionUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_upload_service.ConversionUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_value_rule_service.ConversionValueRuleServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_value_rule_service.ConversionValueRuleServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_audience_service.CustomAudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_audience_service.CustomAudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_conversion_goal_service.CustomConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_conversion_goal_service.CustomConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_interest_service.CustomInterestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.custom_interest_service.CustomInterestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_asset_service.CustomerAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_asset_service.CustomerAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_asset_set_service.CustomerAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_asset_set_service.CustomerAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_client_link_service.CustomerClientLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_client_link_service.CustomerClientLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_customizer_service.CustomerCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_customizer_service.CustomerCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_label_service.CustomerLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_label_service.CustomerLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_manager_link_service.CustomerManagerLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_manager_link_service.CustomerManagerLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_service.CustomerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_service.CustomerServiceAsyncClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaService"],
        version: _V20,
    ) -> google.ads.googleads.v20.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaServiceAsync"],
        version: _V20,
    ) -> google.ads.googleads.v20.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_user_access_service.CustomerUserAccessServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customer_user_access_service.CustomerUserAccessServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customizer_attribute_service.CustomizerAttributeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.customizer_attribute_service.CustomizerAttributeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.data_link_service.DataLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.data_link_service.DataLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.experiment_arm_service.ExperimentArmServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.experiment_arm_service.ExperimentArmServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.experiment_service.ExperimentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.experiment_service.ExperimentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.geo_target_constant_service.GeoTargetConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.geo_target_constant_service.GeoTargetConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.google_ads_field_service.GoogleAdsFieldServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.google_ads_field_service.GoogleAdsFieldServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.google_ads_service.GoogleAdsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.google_ads_service.GoogleAdsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.identity_verification_service.IdentityVerificationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.identity_verification_service.IdentityVerificationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["InvoiceService"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.invoice_service.InvoiceServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["InvoiceServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.invoice_service.InvoiceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_service.KeywordPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_plan_service.KeywordPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["LabelService"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.label_service.LabelServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelServiceAsync"], version: _V20
    ) -> (
        google.ads.googleads.v20.services.services.label_service.LabelServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.local_services_lead_service.LocalServicesLeadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.local_services_lead_service.LocalServicesLeadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.offline_user_data_job_service.OfflineUserDataJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.offline_user_data_job_service.OfflineUserDataJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.payments_account_service.PaymentsAccountServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.payments_account_service.PaymentsAccountServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.product_link_invitation_service.ProductLinkInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.product_link_invitation_service.ProductLinkInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.product_link_service.ProductLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.product_link_service.ProductLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.reach_plan_service.ReachPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.reach_plan_service.ReachPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.recommendation_service.RecommendationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.recommendation_service.RecommendationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.remarketing_action_service.RemarketingActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.remarketing_action_service.RemarketingActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shareable_preview_service.ShareablePreviewServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shareable_preview_service.ShareablePreviewServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shared_criterion_service.SharedCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shared_criterion_service.SharedCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shared_set_service.SharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.shared_set_service.SharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_data_service.UserDataServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_data_service.UserDataServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_list_customer_type_service.UserListCustomerTypeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_list_customer_type_service.UserListCustomerTypeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListService"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_list_service.UserListServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListServiceAsync"], version: _V20
    ) -> google.ads.googleads.v20.services.services.user_list_service.UserListServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.account_budget_proposal_service.AccountBudgetProposalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.account_budget_proposal_service.AccountBudgetProposalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.account_link_service.AccountLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.account_link_service.AccountLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_ad_service.AdGroupAdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_ad_service.AdGroupAdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_asset_service.AdGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_asset_service.AdGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_service.AdGroupCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_criterion_service.AdGroupCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_customizer_service.AdGroupCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_customizer_service.AdGroupCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_label_service.AdGroupLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_label_service.AdGroupLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupService"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.ad_group_service.AdGroupServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AdGroupServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_group_service.AdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_parameter_service.AdParameterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_parameter_service.AdParameterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_service.AdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.ad_service.AdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_asset_service.AssetGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_asset_service.AssetGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_service.AssetGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_service.AssetGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_signal_service.AssetGroupSignalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_group_signal_service.AssetGroupSignalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetService"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.asset_service.AssetServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetServiceAsync"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.asset_service.AssetServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_set_asset_service.AssetSetAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_set_asset_service.AssetSetAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_set_service.AssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.asset_set_service.AssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.audience_insights_service.AudienceInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.audience_insights_service.AudienceInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.audience_service.AudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.audience_service.AudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AutomaticallyCreatedAssetRemovalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["AutomaticallyCreatedAssetRemovalServiceAsync"],
        version: _V21,
    ) -> google.ads.googleads.v21.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.batch_job_service.BatchJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.batch_job_service.BatchJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_strategy_service.BiddingStrategyServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.bidding_strategy_service.BiddingStrategyServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.billing_setup_service.BillingSetupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.billing_setup_service.BillingSetupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.brand_suggestion_service.BrandSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.brand_suggestion_service.BrandSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_asset_service.CampaignAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_asset_service.CampaignAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_asset_set_service.CampaignAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_asset_set_service.CampaignAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_budget_service.CampaignBudgetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_budget_service.CampaignBudgetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_criterion_service.CampaignCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_criterion_service.CampaignCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_customizer_service.CampaignCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_customizer_service.CampaignCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_draft_service.CampaignDraftServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_draft_service.CampaignDraftServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_group_service.CampaignGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_group_service.CampaignGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_label_service.CampaignLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_label_service.CampaignLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_service.CampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_service.CampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_shared_set_service.CampaignSharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.campaign_shared_set_service.CampaignSharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.content_creator_insights_service.ContentCreatorInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.content_creator_insights_service.ContentCreatorInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_action_service.ConversionActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_action_service.ConversionActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_upload_service.ConversionUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_upload_service.ConversionUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_value_rule_service.ConversionValueRuleServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_value_rule_service.ConversionValueRuleServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_audience_service.CustomAudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_audience_service.CustomAudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_conversion_goal_service.CustomConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_conversion_goal_service.CustomConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_interest_service.CustomInterestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.custom_interest_service.CustomInterestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_asset_service.CustomerAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_asset_service.CustomerAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_asset_set_service.CustomerAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_asset_set_service.CustomerAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_client_link_service.CustomerClientLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_client_link_service.CustomerClientLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_customizer_service.CustomerCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_customizer_service.CustomerCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_label_service.CustomerLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_label_service.CustomerLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_manager_link_service.CustomerManagerLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_manager_link_service.CustomerManagerLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_service.CustomerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_service.CustomerServiceAsyncClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaService"],
        version: _V21,
    ) -> google.ads.googleads.v21.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaServiceAsync"],
        version: _V21,
    ) -> google.ads.googleads.v21.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_user_access_service.CustomerUserAccessServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customer_user_access_service.CustomerUserAccessServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customizer_attribute_service.CustomizerAttributeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.customizer_attribute_service.CustomizerAttributeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.data_link_service.DataLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.data_link_service.DataLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.experiment_arm_service.ExperimentArmServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.experiment_arm_service.ExperimentArmServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.experiment_service.ExperimentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.experiment_service.ExperimentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.geo_target_constant_service.GeoTargetConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.geo_target_constant_service.GeoTargetConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.google_ads_field_service.GoogleAdsFieldServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.google_ads_field_service.GoogleAdsFieldServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.google_ads_service.GoogleAdsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.google_ads_service.GoogleAdsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.identity_verification_service.IdentityVerificationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.identity_verification_service.IdentityVerificationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["InvoiceService"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.invoice_service.InvoiceServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["InvoiceServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.invoice_service.InvoiceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_service.KeywordPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_plan_service.KeywordPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["LabelService"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.label_service.LabelServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelServiceAsync"], version: _V21
    ) -> (
        google.ads.googleads.v21.services.services.label_service.LabelServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.local_services_lead_service.LocalServicesLeadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.local_services_lead_service.LocalServicesLeadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.offline_user_data_job_service.OfflineUserDataJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.offline_user_data_job_service.OfflineUserDataJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.payments_account_service.PaymentsAccountServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.payments_account_service.PaymentsAccountServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.product_link_invitation_service.ProductLinkInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.product_link_invitation_service.ProductLinkInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.product_link_service.ProductLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.product_link_service.ProductLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.reach_plan_service.ReachPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.reach_plan_service.ReachPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.recommendation_service.RecommendationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.recommendation_service.RecommendationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.remarketing_action_service.RemarketingActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.remarketing_action_service.RemarketingActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shareable_preview_service.ShareablePreviewServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shareable_preview_service.ShareablePreviewServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shared_criterion_service.SharedCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shared_criterion_service.SharedCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shared_set_service.SharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.shared_set_service.SharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_data_service.UserDataServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_data_service.UserDataServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_list_customer_type_service.UserListCustomerTypeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_list_customer_type_service.UserListCustomerTypeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListService"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_list_service.UserListServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListServiceAsync"], version: _V21
    ) -> google.ads.googleads.v21.services.services.user_list_service.UserListServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.account_budget_proposal_service.AccountBudgetProposalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.account_budget_proposal_service.AccountBudgetProposalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.account_link_service.AccountLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.account_link_service.AccountLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_ad_service.AdGroupAdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_ad_service.AdGroupAdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_asset_service.AdGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_asset_service.AdGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_service.AdGroupCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_criterion_service.AdGroupCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_customizer_service.AdGroupCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_customizer_service.AdGroupCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_label_service.AdGroupLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_label_service.AdGroupLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupService"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.ad_group_service.AdGroupServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AdGroupServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_group_service.AdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_parameter_service.AdParameterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_parameter_service.AdParameterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_service.AdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.ad_service.AdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_generation_service.AssetGenerationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_generation_service.AssetGenerationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_asset_service.AssetGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_asset_service.AssetGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_service.AssetGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_service.AssetGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_signal_service.AssetGroupSignalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_group_signal_service.AssetGroupSignalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetService"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.asset_service.AssetServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetServiceAsync"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.asset_service.AssetServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_set_asset_service.AssetSetAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_set_asset_service.AssetSetAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_set_service.AssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.asset_set_service.AssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.audience_insights_service.AudienceInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.audience_insights_service.AudienceInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.audience_service.AudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.audience_service.AudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AutomaticallyCreatedAssetRemovalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["AutomaticallyCreatedAssetRemovalServiceAsync"],
        version: _V22,
    ) -> google.ads.googleads.v22.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.batch_job_service.BatchJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.batch_job_service.BatchJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_strategy_service.BiddingStrategyServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.bidding_strategy_service.BiddingStrategyServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.billing_setup_service.BillingSetupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.billing_setup_service.BillingSetupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.brand_suggestion_service.BrandSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.brand_suggestion_service.BrandSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_asset_service.CampaignAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_asset_service.CampaignAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_asset_set_service.CampaignAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_asset_set_service.CampaignAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_budget_service.CampaignBudgetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_budget_service.CampaignBudgetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_criterion_service.CampaignCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_criterion_service.CampaignCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_customizer_service.CampaignCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_customizer_service.CampaignCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_draft_service.CampaignDraftServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_draft_service.CampaignDraftServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_goal_config_service.CampaignGoalConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_goal_config_service.CampaignGoalConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_group_service.CampaignGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_group_service.CampaignGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_label_service.CampaignLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_label_service.CampaignLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_service.CampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_service.CampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_shared_set_service.CampaignSharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.campaign_shared_set_service.CampaignSharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.content_creator_insights_service.ContentCreatorInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.content_creator_insights_service.ContentCreatorInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_action_service.ConversionActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_action_service.ConversionActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_upload_service.ConversionUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_upload_service.ConversionUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_value_rule_service.ConversionValueRuleServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_value_rule_service.ConversionValueRuleServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_audience_service.CustomAudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_audience_service.CustomAudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_conversion_goal_service.CustomConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_conversion_goal_service.CustomConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_interest_service.CustomInterestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.custom_interest_service.CustomInterestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_asset_service.CustomerAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_asset_service.CustomerAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_asset_set_service.CustomerAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_asset_set_service.CustomerAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_client_link_service.CustomerClientLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_client_link_service.CustomerClientLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_customizer_service.CustomerCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_customizer_service.CustomerCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_label_service.CustomerLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_label_service.CustomerLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_manager_link_service.CustomerManagerLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_manager_link_service.CustomerManagerLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_service.CustomerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_service.CustomerServiceAsyncClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaService"],
        version: _V22,
    ) -> google.ads.googleads.v22.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaServiceAsync"],
        version: _V22,
    ) -> google.ads.googleads.v22.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_user_access_service.CustomerUserAccessServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customer_user_access_service.CustomerUserAccessServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customizer_attribute_service.CustomizerAttributeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.customizer_attribute_service.CustomizerAttributeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.data_link_service.DataLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.data_link_service.DataLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.experiment_arm_service.ExperimentArmServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.experiment_arm_service.ExperimentArmServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.experiment_service.ExperimentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.experiment_service.ExperimentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.geo_target_constant_service.GeoTargetConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.geo_target_constant_service.GeoTargetConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoalService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.goal_service.GoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoalServiceAsync"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.goal_service.GoalServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.google_ads_field_service.GoogleAdsFieldServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.google_ads_field_service.GoogleAdsFieldServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.google_ads_service.GoogleAdsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.google_ads_service.GoogleAdsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.identity_verification_service.IdentityVerificationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.identity_verification_service.IdentityVerificationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["InvoiceService"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.invoice_service.InvoiceServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["InvoiceServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.invoice_service.InvoiceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_service.KeywordPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_plan_service.KeywordPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["LabelService"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.label_service.LabelServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelServiceAsync"], version: _V22
    ) -> (
        google.ads.googleads.v22.services.services.label_service.LabelServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.local_services_lead_service.LocalServicesLeadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.local_services_lead_service.LocalServicesLeadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.offline_user_data_job_service.OfflineUserDataJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.offline_user_data_job_service.OfflineUserDataJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.payments_account_service.PaymentsAccountServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.payments_account_service.PaymentsAccountServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.product_link_invitation_service.ProductLinkInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.product_link_invitation_service.ProductLinkInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.product_link_service.ProductLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.product_link_service.ProductLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.reach_plan_service.ReachPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.reach_plan_service.ReachPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.recommendation_service.RecommendationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.recommendation_service.RecommendationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.remarketing_action_service.RemarketingActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.remarketing_action_service.RemarketingActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shareable_preview_service.ShareablePreviewServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shareable_preview_service.ShareablePreviewServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shared_criterion_service.SharedCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shared_criterion_service.SharedCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shared_set_service.SharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.shared_set_service.SharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_data_service.UserDataServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_data_service.UserDataServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_list_customer_type_service.UserListCustomerTypeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_list_customer_type_service.UserListCustomerTypeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListService"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_list_service.UserListServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListServiceAsync"], version: _V22
    ) -> google.ads.googleads.v22.services.services.user_list_service.UserListServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.account_budget_proposal_service.AccountBudgetProposalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalService"]
    ) -> google.ads.googleads.v23.services.services.account_budget_proposal_service.AccountBudgetProposalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.account_budget_proposal_service.AccountBudgetProposalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountBudgetProposalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.account_budget_proposal_service.AccountBudgetProposalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.account_link_service.AccountLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkService"]
    ) -> google.ads.googleads.v23.services.services.account_link_service.AccountLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.account_link_service.AccountLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AccountLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.account_link_service.AccountLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdLabelServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_label_service.AdGroupAdLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_service.AdGroupAdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_service.AdGroupAdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_service.AdGroupAdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAdServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_ad_service.AdGroupAdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_service.AdGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_service.AdGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_service.AdGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_service.AdGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupAssetSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_asset_set_service.AdGroupAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupBidModifierServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_bid_modifier_service.AdGroupBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionCustomizerServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_customizer_service.AdGroupCriterionCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionLabelServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_label_service.AdGroupCriterionLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_service.AdGroupCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_service.AdGroupCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_service.AdGroupCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCriterionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_criterion_service.AdGroupCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_customizer_service.AdGroupCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_customizer_service.AdGroupCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_customizer_service.AdGroupCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupCustomizerServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_customizer_service.AdGroupCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_label_service.AdGroupLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelService"]
    ) -> google.ads.googleads.v23.services.services.ad_group_label_service.AdGroupLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_label_service.AdGroupLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupLabelServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_label_service.AdGroupLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupService"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.ad_group_service.AdGroupServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AdGroupService"]
    ) -> (
        google.ads.googleads.v23.services.services.ad_group_service.AdGroupServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AdGroupServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_group_service.AdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdGroupServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_group_service.AdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_parameter_service.AdParameterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterService"]
    ) -> google.ads.googleads.v23.services.services.ad_parameter_service.AdParameterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_parameter_service.AdParameterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdParameterServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_parameter_service.AdParameterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_service.AdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdService"]
    ) -> google.ads.googleads.v23.services.services.ad_service.AdServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AdServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.ad_service.AdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AdServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.ad_service.AdServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_generation_service.AssetGenerationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationService"]
    ) -> google.ads.googleads.v23.services.services.asset_generation_service.AssetGenerationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_generation_service.AssetGenerationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGenerationServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_generation_service.AssetGenerationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_asset_service.AssetGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetService"]
    ) -> google.ads.googleads.v23.services.services.asset_group_asset_service.AssetGroupAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_asset_service.AssetGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupAssetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_group_asset_service.AssetGroupAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterService"]
    ) -> google.ads.googleads.v23.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupListingGroupFilterServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_group_listing_group_filter_service.AssetGroupListingGroupFilterServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_service.AssetGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupService"]
    ) -> google.ads.googleads.v23.services.services.asset_group_service.AssetGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_service.AssetGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_group_service.AssetGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_signal_service.AssetGroupSignalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalService"]
    ) -> google.ads.googleads.v23.services.services.asset_group_signal_service.AssetGroupSignalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_group_signal_service.AssetGroupSignalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetGroupSignalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_group_signal_service.AssetGroupSignalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetService"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.asset_service.AssetServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetService"]
    ) -> (
        google.ads.googleads.v23.services.services.asset_service.AssetServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetServiceAsync"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.asset_service.AssetServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetServiceAsync"]
    ) -> (
        google.ads.googleads.v23.services.services.asset_service.AssetServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_set_asset_service.AssetSetAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetService"]
    ) -> google.ads.googleads.v23.services.services.asset_set_asset_service.AssetSetAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_set_asset_service.AssetSetAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetAssetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_set_asset_service.AssetSetAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_set_service.AssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetService"]
    ) -> google.ads.googleads.v23.services.services.asset_set_service.AssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.asset_set_service.AssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AssetSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.asset_set_service.AssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.audience_insights_service.AudienceInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsService"]
    ) -> google.ads.googleads.v23.services.services.audience_insights_service.AudienceInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.audience_insights_service.AudienceInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceInsightsServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.audience_insights_service.AudienceInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.audience_service.AudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceService"]
    ) -> google.ads.googleads.v23.services.services.audience_service.AudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.audience_service.AudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AudienceServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.audience_service.AudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AutomaticallyCreatedAssetRemovalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["AutomaticallyCreatedAssetRemovalService"]
    ) -> google.ads.googleads.v23.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["AutomaticallyCreatedAssetRemovalServiceAsync"],
        version: _V23,
    ) -> google.ads.googleads.v23.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["AutomaticallyCreatedAssetRemovalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.automatically_created_asset_removal_service.AutomaticallyCreatedAssetRemovalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.batch_job_service.BatchJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobService"]
    ) -> google.ads.googleads.v23.services.services.batch_job_service.BatchJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.batch_job_service.BatchJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BatchJobServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.batch_job_service.BatchJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BenchmarksService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.benchmarks_service.BenchmarksServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BenchmarksService"]
    ) -> google.ads.googleads.v23.services.services.benchmarks_service.BenchmarksServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BenchmarksServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.benchmarks_service.BenchmarksServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BenchmarksServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.benchmarks_service.BenchmarksServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionService"]
    ) -> google.ads.googleads.v23.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingDataExclusionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.bidding_data_exclusion_service.BiddingDataExclusionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentService"]
    ) -> google.ads.googleads.v23.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingSeasonalityAdjustmentServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.bidding_seasonality_adjustment_service.BiddingSeasonalityAdjustmentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_strategy_service.BiddingStrategyServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyService"]
    ) -> google.ads.googleads.v23.services.services.bidding_strategy_service.BiddingStrategyServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.bidding_strategy_service.BiddingStrategyServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BiddingStrategyServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.bidding_strategy_service.BiddingStrategyServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.billing_setup_service.BillingSetupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupService"]
    ) -> google.ads.googleads.v23.services.services.billing_setup_service.BillingSetupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.billing_setup_service.BillingSetupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BillingSetupServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.billing_setup_service.BillingSetupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.brand_suggestion_service.BrandSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionService"]
    ) -> google.ads.googleads.v23.services.services.brand_suggestion_service.BrandSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.brand_suggestion_service.BrandSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["BrandSuggestionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.brand_suggestion_service.BrandSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_asset_service.CampaignAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetService"]
    ) -> google.ads.googleads.v23.services.services.campaign_asset_service.CampaignAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_asset_service.CampaignAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_asset_service.CampaignAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_asset_set_service.CampaignAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetService"]
    ) -> google.ads.googleads.v23.services.services.campaign_asset_set_service.CampaignAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_asset_set_service.CampaignAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignAssetSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_asset_set_service.CampaignAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierService"]
    ) -> google.ads.googleads.v23.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBidModifierServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_bid_modifier_service.CampaignBidModifierServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_budget_service.CampaignBudgetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetService"]
    ) -> google.ads.googleads.v23.services.services.campaign_budget_service.CampaignBudgetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_budget_service.CampaignBudgetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignBudgetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_budget_service.CampaignBudgetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalService"]
    ) -> google.ads.googleads.v23.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignConversionGoalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_conversion_goal_service.CampaignConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_criterion_service.CampaignCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionService"]
    ) -> google.ads.googleads.v23.services.services.campaign_criterion_service.CampaignCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_criterion_service.CampaignCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCriterionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_criterion_service.CampaignCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_customizer_service.CampaignCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerService"]
    ) -> google.ads.googleads.v23.services.services.campaign_customizer_service.CampaignCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_customizer_service.CampaignCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignCustomizerServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_customizer_service.CampaignCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_draft_service.CampaignDraftServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftService"]
    ) -> google.ads.googleads.v23.services.services.campaign_draft_service.CampaignDraftServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_draft_service.CampaignDraftServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignDraftServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_draft_service.CampaignDraftServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_goal_config_service.CampaignGoalConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigService"]
    ) -> google.ads.googleads.v23.services.services.campaign_goal_config_service.CampaignGoalConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_goal_config_service.CampaignGoalConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGoalConfigServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_goal_config_service.CampaignGoalConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_group_service.CampaignGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupService"]
    ) -> google.ads.googleads.v23.services.services.campaign_group_service.CampaignGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_group_service.CampaignGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignGroupServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_group_service.CampaignGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_label_service.CampaignLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelService"]
    ) -> google.ads.googleads.v23.services.services.campaign_label_service.CampaignLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_label_service.CampaignLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLabelServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_label_service.CampaignLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalService"]
    ) -> google.ads.googleads.v23.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignLifecycleGoalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_lifecycle_goal_service.CampaignLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_service.CampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignService"]
    ) -> google.ads.googleads.v23.services.services.campaign_service.CampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_service.CampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_service.CampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_shared_set_service.CampaignSharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetService"]
    ) -> google.ads.googleads.v23.services.services.campaign_shared_set_service.CampaignSharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.campaign_shared_set_service.CampaignSharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CampaignSharedSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.campaign_shared_set_service.CampaignSharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.content_creator_insights_service.ContentCreatorInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsService"]
    ) -> google.ads.googleads.v23.services.services.content_creator_insights_service.ContentCreatorInsightsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.content_creator_insights_service.ContentCreatorInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ContentCreatorInsightsServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.content_creator_insights_service.ContentCreatorInsightsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_action_service.ConversionActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionService"]
    ) -> google.ads.googleads.v23.services.services.conversion_action_service.ConversionActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_action_service.ConversionActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionActionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_action_service.ConversionActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadService"]
    ) -> google.ads.googleads.v23.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionAdjustmentUploadServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_adjustment_upload_service.ConversionAdjustmentUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableService"]
    ) -> google.ads.googleads.v23.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionCustomVariableServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_custom_variable_service.ConversionCustomVariableServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigService"]
    ) -> google.ads.googleads.v23.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionGoalCampaignConfigServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_goal_campaign_config_service.ConversionGoalCampaignConfigServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_upload_service.ConversionUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadService"]
    ) -> google.ads.googleads.v23.services.services.conversion_upload_service.ConversionUploadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_upload_service.ConversionUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionUploadServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_upload_service.ConversionUploadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_service.ConversionValueRuleServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleService"]
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_service.ConversionValueRuleServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_service.ConversionValueRuleServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_service.ConversionValueRuleServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetService"]
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ConversionValueRuleSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.conversion_value_rule_set_service.ConversionValueRuleSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_audience_service.CustomAudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceService"]
    ) -> google.ads.googleads.v23.services.services.custom_audience_service.CustomAudienceServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_audience_service.CustomAudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomAudienceServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.custom_audience_service.CustomAudienceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_conversion_goal_service.CustomConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalService"]
    ) -> google.ads.googleads.v23.services.services.custom_conversion_goal_service.CustomConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_conversion_goal_service.CustomConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomConversionGoalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.custom_conversion_goal_service.CustomConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_interest_service.CustomInterestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestService"]
    ) -> google.ads.googleads.v23.services.services.custom_interest_service.CustomInterestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.custom_interest_service.CustomInterestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomInterestServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.custom_interest_service.CustomInterestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_asset_service.CustomerAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetService"]
    ) -> google.ads.googleads.v23.services.services.customer_asset_service.CustomerAssetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_asset_service.CustomerAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_asset_service.CustomerAssetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_asset_set_service.CustomerAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetService"]
    ) -> google.ads.googleads.v23.services.services.customer_asset_set_service.CustomerAssetSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_asset_set_service.CustomerAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerAssetSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_asset_set_service.CustomerAssetSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_client_link_service.CustomerClientLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkService"]
    ) -> google.ads.googleads.v23.services.services.customer_client_link_service.CustomerClientLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_client_link_service.CustomerClientLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerClientLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_client_link_service.CustomerClientLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalService"]
    ) -> google.ads.googleads.v23.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerConversionGoalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_conversion_goal_service.CustomerConversionGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_customizer_service.CustomerCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerService"]
    ) -> google.ads.googleads.v23.services.services.customer_customizer_service.CustomerCustomizerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_customizer_service.CustomerCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerCustomizerServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_customizer_service.CustomerCustomizerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_label_service.CustomerLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelService"]
    ) -> google.ads.googleads.v23.services.services.customer_label_service.CustomerLabelServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_label_service.CustomerLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLabelServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_label_service.CustomerLabelServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalService"]
    ) -> google.ads.googleads.v23.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerLifecycleGoalServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_lifecycle_goal_service.CustomerLifecycleGoalServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_manager_link_service.CustomerManagerLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkService"]
    ) -> google.ads.googleads.v23.services.services.customer_manager_link_service.CustomerManagerLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_manager_link_service.CustomerManagerLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerManagerLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_manager_link_service.CustomerManagerLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionService"]
    ) -> google.ads.googleads.v23.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerNegativeCriterionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_negative_criterion_service.CustomerNegativeCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_service.CustomerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerService"]
    ) -> google.ads.googleads.v23.services.services.customer_service.CustomerServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_service.CustomerServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_service.CustomerServiceAsyncClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaService"],
        version: _V23,
    ) -> google.ads.googleads.v23.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerSkAdNetworkConversionValueSchemaService"]
    ) -> google.ads.googleads.v23.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceClient: ...
    @overload
    def get_service(
        self,
        name: Literal["CustomerSkAdNetworkConversionValueSchemaServiceAsync"],
        version: _V23,
    ) -> google.ads.googleads.v23.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerSkAdNetworkConversionValueSchemaServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_sk_ad_network_conversion_value_schema_service.CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationService"]
    ) -> google.ads.googleads.v23.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessInvitationServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_user_access_invitation_service.CustomerUserAccessInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_user_access_service.CustomerUserAccessServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessService"]
    ) -> google.ads.googleads.v23.services.services.customer_user_access_service.CustomerUserAccessServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customer_user_access_service.CustomerUserAccessServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomerUserAccessServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customer_user_access_service.CustomerUserAccessServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customizer_attribute_service.CustomizerAttributeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeService"]
    ) -> google.ads.googleads.v23.services.services.customizer_attribute_service.CustomizerAttributeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.customizer_attribute_service.CustomizerAttributeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["CustomizerAttributeServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.customizer_attribute_service.CustomizerAttributeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.data_link_service.DataLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkService"]
    ) -> google.ads.googleads.v23.services.services.data_link_service.DataLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.data_link_service.DataLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["DataLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.data_link_service.DataLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.experiment_arm_service.ExperimentArmServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmService"]
    ) -> google.ads.googleads.v23.services.services.experiment_arm_service.ExperimentArmServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.experiment_arm_service.ExperimentArmServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentArmServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.experiment_arm_service.ExperimentArmServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.experiment_service.ExperimentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentService"]
    ) -> google.ads.googleads.v23.services.services.experiment_service.ExperimentServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.experiment_service.ExperimentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ExperimentServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.experiment_service.ExperimentServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.geo_target_constant_service.GeoTargetConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantService"]
    ) -> google.ads.googleads.v23.services.services.geo_target_constant_service.GeoTargetConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.geo_target_constant_service.GeoTargetConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GeoTargetConstantServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.geo_target_constant_service.GeoTargetConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoalService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.goal_service.GoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoalService"]
    ) -> google.ads.googleads.v23.services.services.goal_service.GoalServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoalServiceAsync"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.goal_service.GoalServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["GoalServiceAsync"]
    ) -> (
        google.ads.googleads.v23.services.services.goal_service.GoalServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.google_ads_field_service.GoogleAdsFieldServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldService"]
    ) -> google.ads.googleads.v23.services.services.google_ads_field_service.GoogleAdsFieldServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.google_ads_field_service.GoogleAdsFieldServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsFieldServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.google_ads_field_service.GoogleAdsFieldServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.google_ads_service.GoogleAdsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsService"]
    ) -> google.ads.googleads.v23.services.services.google_ads_service.GoogleAdsServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.google_ads_service.GoogleAdsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["GoogleAdsServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.google_ads_service.GoogleAdsServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.identity_verification_service.IdentityVerificationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationService"]
    ) -> google.ads.googleads.v23.services.services.identity_verification_service.IdentityVerificationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.identity_verification_service.IdentityVerificationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IdentityVerificationServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.identity_verification_service.IdentityVerificationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IncentiveService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.incentive_service.IncentiveServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IncentiveService"]
    ) -> google.ads.googleads.v23.services.services.incentive_service.IncentiveServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["IncentiveServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.incentive_service.IncentiveServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["IncentiveServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.incentive_service.IncentiveServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["InvoiceService"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.invoice_service.InvoiceServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["InvoiceService"]
    ) -> (
        google.ads.googleads.v23.services.services.invoice_service.InvoiceServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["InvoiceServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.invoice_service.InvoiceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["InvoiceServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.invoice_service.InvoiceServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupKeywordServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_keyword_service.KeywordPlanAdGroupKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanAdGroupServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_ad_group_service.KeywordPlanAdGroupServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignKeywordServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_keyword_service.KeywordPlanCampaignKeywordServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanCampaignServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_campaign_service.KeywordPlanCampaignServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanIdeaServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_idea_service.KeywordPlanIdeaServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_service.KeywordPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanService"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_service.KeywordPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_plan_service.KeywordPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordPlanServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_plan_service.KeywordPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantService"]
    ) -> google.ads.googleads.v23.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["KeywordThemeConstantServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.keyword_theme_constant_service.KeywordThemeConstantServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["LabelService"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.label_service.LabelServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelService"]
    ) -> (
        google.ads.googleads.v23.services.services.label_service.LabelServiceClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelServiceAsync"], version: _V23
    ) -> (
        google.ads.googleads.v23.services.services.label_service.LabelServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LabelServiceAsync"]
    ) -> (
        google.ads.googleads.v23.services.services.label_service.LabelServiceAsyncClient
    ): ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.local_services_lead_service.LocalServicesLeadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadService"]
    ) -> google.ads.googleads.v23.services.services.local_services_lead_service.LocalServicesLeadServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.local_services_lead_service.LocalServicesLeadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["LocalServicesLeadServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.local_services_lead_service.LocalServicesLeadServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.offline_user_data_job_service.OfflineUserDataJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobService"]
    ) -> google.ads.googleads.v23.services.services.offline_user_data_job_service.OfflineUserDataJobServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.offline_user_data_job_service.OfflineUserDataJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["OfflineUserDataJobServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.offline_user_data_job_service.OfflineUserDataJobServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.payments_account_service.PaymentsAccountServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountService"]
    ) -> google.ads.googleads.v23.services.services.payments_account_service.PaymentsAccountServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.payments_account_service.PaymentsAccountServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["PaymentsAccountServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.payments_account_service.PaymentsAccountServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.product_link_invitation_service.ProductLinkInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationService"]
    ) -> google.ads.googleads.v23.services.services.product_link_invitation_service.ProductLinkInvitationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.product_link_invitation_service.ProductLinkInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkInvitationServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.product_link_invitation_service.ProductLinkInvitationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.product_link_service.ProductLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkService"]
    ) -> google.ads.googleads.v23.services.services.product_link_service.ProductLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.product_link_service.ProductLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ProductLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.product_link_service.ProductLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.reach_plan_service.ReachPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanService"]
    ) -> google.ads.googleads.v23.services.services.reach_plan_service.ReachPlanServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.reach_plan_service.ReachPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ReachPlanServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.reach_plan_service.ReachPlanServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.recommendation_service.RecommendationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationService"]
    ) -> google.ads.googleads.v23.services.services.recommendation_service.RecommendationServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.recommendation_service.RecommendationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.recommendation_service.RecommendationServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionService"]
    ) -> google.ads.googleads.v23.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RecommendationSubscriptionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.recommendation_subscription_service.RecommendationSubscriptionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.remarketing_action_service.RemarketingActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionService"]
    ) -> google.ads.googleads.v23.services.services.remarketing_action_service.RemarketingActionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.remarketing_action_service.RemarketingActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["RemarketingActionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.remarketing_action_service.RemarketingActionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shareable_preview_service.ShareablePreviewServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewService"]
    ) -> google.ads.googleads.v23.services.services.shareable_preview_service.ShareablePreviewServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shareable_preview_service.ShareablePreviewServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ShareablePreviewServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.shareable_preview_service.ShareablePreviewServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shared_criterion_service.SharedCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionService"]
    ) -> google.ads.googleads.v23.services.services.shared_criterion_service.SharedCriterionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shared_criterion_service.SharedCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedCriterionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.shared_criterion_service.SharedCriterionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shared_set_service.SharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetService"]
    ) -> google.ads.googleads.v23.services.services.shared_set_service.SharedSetServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.shared_set_service.SharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SharedSetServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.shared_set_service.SharedSetServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingService"]
    ) -> google.ads.googleads.v23.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSettingServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.smart_campaign_setting_service.SmartCampaignSettingServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestService"]
    ) -> google.ads.googleads.v23.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["SmartCampaignSuggestServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.smart_campaign_suggest_service.SmartCampaignSuggestServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkService"]
    ) -> google.ads.googleads.v23.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["ThirdPartyAppAnalyticsLinkServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.third_party_app_analytics_link_service.ThirdPartyAppAnalyticsLinkServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionService"]
    ) -> google.ads.googleads.v23.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["TravelAssetSuggestionServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.travel_asset_suggestion_service.TravelAssetSuggestionServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_data_service.UserDataServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataService"]
    ) -> google.ads.googleads.v23.services.services.user_data_service.UserDataServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_data_service.UserDataServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserDataServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.user_data_service.UserDataServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_list_customer_type_service.UserListCustomerTypeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeService"]
    ) -> google.ads.googleads.v23.services.services.user_list_customer_type_service.UserListCustomerTypeServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_list_customer_type_service.UserListCustomerTypeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListCustomerTypeServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.user_list_customer_type_service.UserListCustomerTypeServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListService"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_list_service.UserListServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListService"]
    ) -> google.ads.googleads.v23.services.services.user_list_service.UserListServiceClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListServiceAsync"], version: _V23
    ) -> google.ads.googleads.v23.services.services.user_list_service.UserListServiceAsyncClient: ...
    @overload
    def get_service(
        self, name: Literal["UserListServiceAsync"]
    ) -> google.ads.googleads.v23.services.services.user_list_service.UserListServiceAsyncClient: ...
    @overload
    def get_service(self, name: str, version: _V = "v23") -> Any: ...
    # End of autogenerated service overloads
